#include <iostream>
#include <functional>

#include "marley/marley_utils.hh"
#include "marley/MassTable.hh"

const marley::MassTable& marley::MassTable::Instance() {

  // Create the mass table using a static variable. This ensures
  // that the singleton instance is only created once.
  static std::unique_ptr<marley::MassTable>
    the_instance(new marley::MassTable());

  // Return a reference to the singleton instance
  return *the_instance;
}

double marley::MassTable::liquid_drop_model_atomic_mass(int Z, int A) const {
  return liquid_drop_model_mass_excess(Z, A) + micro_amu_*1e6*A;
}

double marley::MassTable::get_particle_mass(int particle_id) const {
  int id = particle_id;
  // The lookup table only includes entries for particles (as opposed to
  // antiparticles), so flip the sign of the input particle id for the
  // lookup if it represents an antiparticle.
  if (id < 0) id *= -1;
  // Find the particle's mass in the lookup table, and convert its
  // value from micro-amu to MeV
  return micro_amu_ * particle_masses_.at(id);
}

double marley::MassTable::get_atomic_mass(int nucleus_pid, bool theory_ok) const
{
  bool exp;
  double mass = lookup_atomic_mass(nucleus_pid, exp,
    theory_ok);
  if (exp) mass *= micro_amu_;
  return mass;
}

double marley::MassTable::lookup_atomic_mass(int nucleus_pid, bool& exp,
  bool theory_ok) const
{
  // Find the atom's mass (in micro-amu) in the lookup table using its
  // nucleus's particle ID number. If it can't be found, either return a
  // theoretical mass using the liquid drop model or throw an error.
  // std::unordered_map<int, double>::iterator search
  auto search = atomic_masses_.find(nucleus_pid);

  // If the mass was found in the lookup table, return it and flag it as an
  // experimental value
  if (search != atomic_masses_.end()) {
    exp = true;
    return search->second;
  }
  // Otherwise, return a theoretical estimate using the liquid drop model or
  // throw an error depending on whether the user has indicated that using a
  // theoretical estimate is acceptable. For either case, set the experimental
  // flag to false.
  else {
    exp = false;

    int Z = marley_utils::get_particle_Z(nucleus_pid);
    int A = marley_utils::get_particle_A(nucleus_pid);

    if (theory_ok) {
      return liquid_drop_model_atomic_mass(Z, A);
    }
    else throw marley::Error(std::string("Entry for Z = ")
      + std::to_string(Z) + " and A = " + std::to_string(A)
      + " not found in the MARLEY atomic mass table.");
  }
}

double marley::MassTable::lookup_atomic_mass(int Z, int A, bool& exp,
  bool theory_ok) const
{
  int nucleus_pid = marley_utils::get_nucleus_pid(Z, A);

  auto search = atomic_masses_.find(nucleus_pid);

  // If the mass was found in the lookup table, return it and flag it as an
  // experimental value
  if (search != atomic_masses_.end()) {
    exp = true;
    return search->second;
  }
  // Otherwise, return a theoretical estimate using the liquid drop model or
  // throw an error depending on whether the user has indicated that using a
  // theoretical estimate is acceptable. For either case, set the experimental
  // flag to false.
  else {
    exp = false;

    if (theory_ok) {
      return liquid_drop_model_atomic_mass(Z, A);
    }
    else throw marley::Error(std::string("Entry for Z = ")
      + std::to_string(Z) + " and A = " + std::to_string(A)
      + " not found in the MARLEY atomic mass table.");
  }
}

double marley::MassTable::get_binding_energy(int Z, int A, bool theory_ok) const
{
  int N = A - Z;
  double m_hydrogen_1 = atomic_masses_.at(1000010010);
  double mn = particle_masses_.at(marley_utils::NEUTRON);

  bool exp;
  double mN = lookup_atomic_mass(Z, A, exp, theory_ok);

  // Experimental masses are given in micro-amu, while our liquid drop model
  // estimates are given in MeV, so adjust the calculation appropriately
  // depending on which unit we are using for mN.
  if (exp) return micro_amu_ * (Z*m_hydrogen_1 + N*mn - mN);
  else return micro_amu_ * (Z*m_hydrogen_1 + N*mn) - mN;
}

double marley::MassTable::get_mass_excess(int Z, int A, bool theory_ok) const
{
  bool exp;
  double mN = lookup_atomic_mass(Z, A, exp, theory_ok);
  if (exp) return micro_amu_*(mN - A*1e6);
  else return mN - micro_amu_*A*1e6;
}

double marley::MassTable::get_atomic_mass(int Z, int A, bool theory_ok) const {
  bool exp;
  double mass = lookup_atomic_mass(Z, A, exp, theory_ok);
  if (exp) mass *= micro_amu_;
  return mass;
}

double marley::MassTable::get_fragment_separation_energy(int Z, int A, int pid,
  bool theory_ok) const
{
  int Zx = marley_utils::get_particle_Z(pid);
  int Zf = Z - Zx;
  int Af = A - marley_utils::get_particle_A(pid);

  double extra_mass = Zx*particle_masses_.at(marley_utils::ELECTRON)
    + particle_masses_.at(pid);

  bool exp_i, exp_f;
  double m_atom_initial = lookup_atomic_mass(Z, A, exp_i, theory_ok);
  double m_atom_final = lookup_atomic_mass(Zf, Af, exp_f, theory_ok);

  if (exp_i) {
    if (exp_f) return micro_amu_*(m_atom_final - m_atom_initial + extra_mass);
    else return m_atom_final + micro_amu_*(extra_mass - m_atom_initial);
  }
  else if (exp_f) return micro_amu_*(m_atom_final + extra_mass)
    - m_atom_initial;
  else return micro_amu_*extra_mass + m_atom_final - m_atom_initial;
}

/// @details The liquid drop model parameters used here are based on those
/// given in <a href="http://dx.doi.org/10.1016/j.nuclphysa.2008.06.005">A. J.
/// Koning, et al., Nucl. Phys. A 810 (2008) pp. 13-76</a> for use with the
/// back-shifted Fermi gas nuclear level density model.
double marley::MassTable::liquid_drop_model_mass_excess(int Z, int A) const {

  // Liquid drop model parameters (taken from paper by A. J. Koning, et al.)
  static constexpr double Mn = 8.07144; // MeV
  static constexpr double MH = 7.28899; // MeV
  static constexpr double a1 = 15.677; // MeV
  static constexpr double a2 = 18.56; // MeV
  static constexpr double kappa = 1.79;
  static constexpr double c3 = 0.717; // MeV
  static constexpr double c4 = 1.21129; // MeV

  int N = A - Z;

  double kappa_term = kappa * std::pow((N - Z) / static_cast<double>(A), 2);
  double c1 = a1 * (1 - kappa_term);
  double c2 = a2 * (1 - kappa_term);

  double Evol = -c1 * A;
  double Esur = c2 * std::pow(A, 2.0/3.0);
  double Ecoul = (c3 / std::pow(A, 1.0/3.0) - c4 / A) * std::pow(Z, 2);

  double delta_LDM = 0;
  bool z_odd = Z % 2;
  bool n_odd = N % 2;

  // delta_LDM will be zero if the nucleus is odd-even
  if (z_odd && n_odd) delta_LDM = 11/std::sqrt(A);
  else if (!z_odd && !n_odd) delta_LDM = -11/std::sqrt(A);

  return Mn * N + MH * Z + Evol + Esur + Ecoul + delta_LDM;
}

////////////////////////////////////////////////////////////////////////////////
// MARLEY particle and atomic mass data
// Prepared on 4 June 2015 by S. J. Gardiner
//
// Particle IDs conform to the 2013 revision of the Particle Data Group Monte
// Carlo Particle Numbering Scheme
// (see http://pdg.lbl.gov/2014/reviews/rpp2014-rev-monte-carlo-numbering.pdf)
//
// Atomic masses are taken from the 2012 Atomic Mass Evaluation
// (see http://amdc.impcas.ac.cn/evaluation/data2012/ame.html)
//
// Particle masses were taken from the
// "CODATA Internationally recommended 2010 values of the Fundamental Physical
// Constants" (see http://physics.nist.gov/cuu/Constants/index.html)
// except for the neutron mass (2112), which was taken from AME2012.
//
// All masses in this dataset are given in micro-amu. They must be converted to
// MeV by all public member functions of marley::MassTable. The conversion
// factor is 1 micro-amu = 0.000931494061 MeV.
////////////////////////////////////////////////////////////////////////////////
namespace {
  // Lookup table for particle masses. Keys are PDG particle
  // ID numbers, values are masses in micro-amu.
  const std::unordered_map<int, double> particle_masses = {
    {11, 548.57990946}, // e-
    {12, 0.0}, // nu_e
    {13, marley_utils::m_mu}, // mu-
    {14, 0.0}, // nu_mu
    {15, 1907490}, // tau-
    {16, 0.0}, // nu_tau
    {22, 0.0}, // photon
    {2112, 1008664.91585}, // neutron
    {2212, 1007276.466812}, // proton
    {1000010020, 2013553.212712}, // deuteron
    {1000010030, 3015500.7134}, // triton
    {1000020030, 3014932.2468}, // helion
    {1000020040, 4001506.179125}, // alpha
  };

  // Lookup table for atomic masses. Keys are PDG particle
  // ID numbers for the nuclei, values are masses in micro-amu.
  const std::unordered_map<int, double> atomic_masses = {
    {1000010010, 1007825.03223},
    {1000010020, 2014101.77812},
    {1000010030, 3016049.27791},
    {1000020030, 3016029.32008},
    {1000030030, 3030775.},
    {1000010040, 4026431.864},
    {1000020040, 4002603.25413},
    {1000030040, 4027185.559},
    {1000010050, 5035311.489},
    {1000020050, 5012057.224},
    {1000030050, 5012537.800},
    {1000040050, 5039870.},
    {1000010060, 6044955.433},
    {1000020060, 6018885.891},
    {1000030060, 6015122.88742},
    {1000040060, 6019726.411},
    {1000050060, 6050800.},
    {1000010070, 7052749.},
    {1000020070, 7027990.654},
    {1000030070, 7016003.43659},
    {1000040070, 7016928.717},
    {1000050070, 7029712.000},
    {1000020080, 8033934.390},
    {1000030080, 8022486.246},
    {1000040080, 8005305.102},
    {1000050080, 8024607.326},
    {1000060080, 8037643.042},
    {1000020090, 9043946.494},
    {1000030090, 9026790.191},
    {1000040090, 9012183.065},
    {1000050090, 9013329.649},
    {1000060090, 9031037.204},
    {1000020100, 10052788.655},
    {1000030100, 10035483.453},
    {1000040100, 10013534.695},
    {1000050100, 10012936.949},
    {1000060100, 10016853.307},
    {1000070100, 10041653.630},
    {1000030110, 11043723.581},
    {1000040110, 11021661.081},
    {1000050110, 11009305.355},
    {1000060110, 11011433.563},
    {1000070110, 11026091.034},
    {1000030120, 12052517.322},
    {1000040120, 12026922.082},
    {1000050120, 12014352.658},
    {1000060120, 12000000.0},
    {1000070120, 12018613.187},
    {1000080120, 12034261.836},
    {1000030130, 13062631.523},
    {1000040130, 13036134.506},
    {1000050130, 13017780.166},
    {1000060130, 13003354.83507},
    {1000070130, 13005738.609},
    {1000080130, 13024815.446},
    {1000040140, 14042892.920},
    {1000050140, 14025404.012},
    {1000060140, 14003241.98843},
    {1000070140, 14003074.00443},
    {1000080140, 14008596.359},
    {1000090140, 14034315.207},
    {1000040150, 15053420.},
    {1000050150, 15031087.680},
    {1000060150, 15010599.256},
    {1000070150, 15000108.89888},
    {1000080150, 15003065.618},
    {1000090150, 15018042.853},
    {1000040160, 16061672.036},
    {1000050160, 16039841.663},
    {1000060160, 16014701.252},
    {1000070160, 16006101.925},
    {1000080160, 15994914.61957},
    {1000090160, 16011465.725},
    {1000100160, 16025750.197},
    {1000050170, 17046989.906},
    {1000060170, 17022577.470},
    {1000070170, 17008448.873},
    {1000080170, 16999131.75650},
    {1000090170, 17002095.237},
    {1000100170, 17017713.963},
    {1000050180, 18055660.189},
    {1000060180, 18026750.708},
    {1000070180, 18014077.565},
    {1000080180, 17999159.61286},
    {1000090180, 18000937.325},
    {1000100180, 18005708.703},
    {1000110180, 18026878.252},
    {1000050190, 19063100.},
    {1000060190, 19034796.372},
    {1000070190, 19017021.603},
    {1000080190, 19003577.970},
    {1000090190, 18998403.16273},
    {1000100190, 19001880.907},
    {1000110190, 19013880.272},
    {1000120190, 19034169.186},
    {1000050200, 20072070.},
    {1000060200, 20040319.754},
    {1000070200, 20023365.807},
    {1000080200, 20004075.354},
    {1000090200, 19999981.252},
    {1000100200, 19992440.17617},
    {1000110200, 20007354.426},
    {1000120200, 20018850.004},
    {1000050210, 21081290.},
    {1000060210, 21049000.},
    {1000070210, 21027108.240},
    {1000080210, 21008654.813},
    {1000090210, 20999948.889},
    {1000100210, 20993846.685},
    {1000110210, 20997654.695},
    {1000120210, 21011716.140},
    {1000130210, 21028975.},
    {1000060220, 22057531.496},
    {1000070220, 22034394.934},
    {1000080220, 22009966.057},
    {1000090220, 22002998.813},
    {1000100220, 21991385.114},
    {1000110220, 21994437.411},
    {1000120220, 21999570.648},
    {1000130220, 22019540.},
    {1000140220, 22035790.},
    {1000060230, 23068890.},
    {1000070230, 23041140.},
    {1000080230, 23015695.922},
    {1000090230, 23003556.696},
    {1000100230, 22994466.905},
    {1000110230, 22989769.28196},
    {1000120230, 22994124.208},
    {1000130230, 23007244.351},
    {1000140230, 23025440.},
    {1000070240, 24050390.},
    {1000080240, 24019861.000},
    {1000090240, 24008115.485},
    {1000100240, 23993610.650},
    {1000110240, 23990962.950},
    {1000120240, 23985041.697},
    {1000130240, 23999948.883},
    {1000140240, 24011534.538},
    {1000150240, 24035770.},
    {1000070250, 25060100.},
    {1000080250, 25029358.986},
    {1000090250, 25012199.229},
    {1000100250, 24997788.707},
    {1000110250, 24989953.969},
    {1000120250, 24985836.976},
    {1000130250, 24990428.102},
    {1000140250, 25004108.808},
    {1000150250, 25021190.},
    {1000080260, 26037287.450},
    {1000090260, 26020037.768},
    {1000100260, 26000514.705},
    {1000110260, 25992634.649},
    {1000120260, 25982592.968},
    {1000130260, 25986891.904},
    {1000140260, 25992333.845},
    {1000150260, 26011780.},
    {1000160260, 26029070.},
    {1000080270, 27047720.},
    {1000090270, 27026441.000},
    {1000100270, 27007553.268},
    {1000110270, 26994076.531},
    {1000120270, 26984340.624},
    {1000130270, 26981538.531},
    {1000140270, 26986704.811},
    {1000150270, 26999224.406},
    {1000160270, 27018280.},
    {1000080280, 28055910.},
    {1000090280, 28035342.095},
    {1000100280, 28012121.998},
    {1000110280, 27998939.000},
    {1000120280, 27983876.728},
    {1000130280, 27981910.210},
    {1000140280, 27976926.53465},
    {1000150280, 27992326.585},
    {1000160280, 28004372.766},
    {1000170280, 28029540.},
    {1000090290, 29042540.},
    {1000100290, 29019753.000},
    {1000110290, 29002877.073},
    {1000120290, 28988617.393},
    {1000130290, 28980456.490},
    {1000140290, 28976494.66490},
    {1000150290, 28981800.794},
    {1000160290, 28996611.456},
    {1000170290, 29014780.},
    {1000090300, 30051650.},
    {1000100300, 30024734.000},
    {1000110300, 30009097.932},
    {1000120300, 29990462.926},
    {1000130300, 29982960.220},
    {1000140300, 29973770.136},
    {1000150300, 29978313.753},
    {1000160300, 29984907.033},
    {1000170300, 30004770.},
    {1000180300, 30023070.},
    {1000090310, 31059709.},
    {1000100310, 31033087.000},
    {1000110310, 31013162.656},
    {1000120310, 30996648.032},
    {1000130310, 30983945.171},
    {1000140310, 30975363.194},
    {1000150310, 30973761.99842},
    {1000160310, 30979557.007},
    {1000170310, 30992414.203},
    {1000180310, 31012124.},
    {1000100320, 32039720.},
    {1000110320, 32020193.000},
    {1000120320, 31999110.239},
    {1000130320, 31988085.239},
    {1000140320, 31974151.539},
    {1000150320, 31973907.643},
    {1000160320, 31972071.17441},
    {1000170320, 31985684.637},
    {1000180320, 31997637.826},
    {1000190320, 32022650.},
    {1000100330, 33049380.},
    {1000110330, 33025730.},
    {1000120330, 33005327.145},
    {1000130330, 32990908.977},
    {1000140330, 32977976.964},
    {1000150330, 32971725.694},
    {1000160330, 32971458.90982},
    {1000170330, 32977451.989},
    {1000180330, 32989925.546},
    {1000190330, 33007560.},
    {1000100340, 34056728.},
    {1000110340, 34033590.},
    {1000120340, 34008935.481},
    {1000130340, 33996705.398},
    {1000140340, 33978575.569},
    {1000150340, 33973645.886},
    {1000160340, 33967867.004},
    {1000170340, 33973762.485},
    {1000180340, 33980270.090},
    {1000190340, 33998690.},
    {1000200340, 34014870.},
    {1000110350, 35040623.},
    {1000120350, 35016790.000},
    {1000130350, 34999764.000},
    {1000140350, 34984583.476},
    {1000150350, 34973314.062},
    {1000160350, 34969032.310},
    {1000170350, 34968852.682},
    {1000180350, 34975257.586},
    {1000190350, 34988005.407},
    {1000200350, 35005140.},
    {1000110360, 36049288.},
    {1000120360, 36021879.000},
    {1000130360, 36006388.000},
    {1000140360, 35986695.219},
    {1000150360, 35978259.625},
    {1000160360, 35967080.706},
    {1000170360, 35968306.809},
    {1000180360, 35967545.105},
    {1000190360, 35981302.010},
    {1000200360, 35993074.404},
    {1000210360, 36016480.},
    {1000110370, 37057051.},
    {1000120370, 37030370.},
    {1000130370, 37010531.000},
    {1000140370, 36992920.740},
    {1000150370, 36979606.841},
    {1000160370, 36971125.514},
    {1000170370, 36965902.602},
    {1000180370, 36966776.331},
    {1000190370, 36973375.889},
    {1000200370, 36985897.852},
    {1000210370, 37003740.},
    {1000120380, 38036580.},
    {1000130380, 38017402.000},
    {1000140380, 37995523.000},
    {1000150380, 37984251.583},
    {1000160380, 37971163.328},
    {1000170380, 37968010.436},
    {1000180380, 37962732.106},
    {1000190380, 37969081.117},
    {1000200380, 37976319.224},
    {1000210380, 37995120.},
    {1000220380, 38011450.},
    {1000120390, 39045384.},
    {1000130390, 39022540.},
    {1000140390, 39002491.000},
    {1000150390, 38986227.208},
    {1000160390, 38975134.197},
    {1000170390, 38968008.176},
    {1000180390, 38964313.038},
    {1000190390, 38963706.48643},
    {1000200390, 38970710.813},
    {1000210390, 38984784.968},
    {1000220390, 39002360.},
    {1000120400, 40052180.},
    {1000130400, 40030030.},
    {1000140400, 40005829.000},
    {1000150400, 39991331.748},
    {1000160400, 39975482.562},
    {1000170400, 39970415.469},
    {1000180400, 39962383.12372},
    {1000190400, 39963998.166},
    {1000200400, 39962590.863},
    {1000210400, 39977967.291},
    {1000220400, 39990498.719},
    {1000230400, 40012760.},
    {1000130410, 41036380.},
    {1000140410, 41013011.000},
    {1000150410, 40994654.000},
    {1000160410, 40979593.451},
    {1000170410, 40970684.525},
    {1000180410, 40964500.570},
    {1000190410, 40961825.25792},
    {1000200410, 40962277.924},
    {1000210410, 40969251.105},
    {1000220410, 40983148.000},
    {1000230410, 41000210.},
    {1000130420, 42043840.},
    {1000140420, 42017780.},
    {1000150420, 42001084.000},
    {1000160420, 41981065.100},
    {1000170420, 41973254.804},
    {1000180420, 41963045.736},
    {1000190420, 41962402.306},
    {1000200420, 41958617.830},
    {1000210420, 41965516.532},
    {1000220420, 41973049.034},
    {1000230420, 41991820.},
    {1000240420, 42006700.},
    {1000130430, 43051470.},
    {1000140430, 43024800.},
    {1000150430, 43005024.000},
    {1000160430, 42986907.635},
    {1000170430, 42973888.584},
    {1000180430, 42965636.055},
    {1000190430, 42960734.702},
    {1000200430, 42958766.438},
    {1000210430, 42961150.474},
    {1000220430, 42968522.520},
    {1000230430, 42980766.000},
    {1000240430, 42997530.},
    {1000140440, 44030610.},
    {1000150440, 44011210.},
    {1000160440, 43990118.848},
    {1000170440, 43977874.543},
    {1000180440, 43964923.815},
    {1000190440, 43961586.985},
    {1000200440, 43955481.561},
    {1000210440, 43959402.875},
    {1000220440, 43959689.949},
    {1000230440, 43974110.000},
    {1000240440, 43985360.},
    {1000250440, 44007150.},
    {1000140450, 45039950.},
    {1000150450, 45016450.},
    {1000160450, 44995717.000},
    {1000170450, 44980290.000},
    {1000180450, 44968039.733},
    {1000190450, 44960691.493},
    {1000200450, 44956186.350},
    {1000210450, 44955908.275},
    {1000220450, 44958121.983},
    {1000230450, 44965774.820},
    {1000240450, 44979050.000},
    {1000250450, 44994490.},
    {1000260450, 45014419.},
    {1000150460, 46024460.},
    {1000160460, 46000040.},
    {1000170460, 45985174.000},
    {1000180460, 45968082.712},
    {1000190460, 45961981.586},
    {1000200460, 45953689.023},
    {1000210460, 45955168.257},
    {1000220460, 45952627.718},
    {1000230460, 45960198.775},
    {1000240460, 45968358.861},
    {1000250460, 45986090.},
    {1000260460, 46000630.},
    {1000150470, 47031390.},
    {1000160470, 47007950.},
    {1000170470, 46989160.},
    {1000180470, 46972934.865},
    {1000190470, 46961661.614},
    {1000200470, 46954542.430},
    {1000210470, 46952403.740},
    {1000220470, 46951758.787},
    {1000230470, 46954904.914},
    {1000240470, 46962897.359},
    {1000250470, 46975775.000},
    {1000260470, 46991850.},
    {1000270470, 47010570.},
    {1000160480, 48013700.},
    {1000170480, 47995640.},
    {1000180480, 47975910.},
    {1000190480, 47965341.186},
    {1000200480, 47952522.765},
    {1000210480, 47952223.611},
    {1000220480, 47947941.979},
    {1000230480, 47952252.223},
    {1000240480, 47954029.061},
    {1000250480, 47968520.000},
    {1000260480, 47980230.},
    {1000270480, 48000930.},
    {1000280480, 48017688.},
    {1000160490, 49022762.},
    {1000170490, 49001230.},
    {1000180490, 48981900.},
    {1000190490, 48968210.755},
    {1000200490, 48955662.736},
    {1000210490, 48950014.629},
    {1000220490, 48947865.676},
    {1000230490, 48948511.795},
    {1000240490, 48951333.349},
    {1000250490, 48959595.297},
    {1000260490, 48973429.000},
    {1000270490, 48988910.},
    {1000280490, 49007700.},
    {1000170500, 50009050.},
    {1000180500, 49986130.},
    {1000190500, 49972380.017},
    {1000200500, 49957499.217},
    {1000210500, 49952176.274},
    {1000220500, 49944786.889},
    {1000230500, 49947156.014},
    {1000240500, 49946041.833},
    {1000250500, 49954237.781},
    {1000260500, 49962974.929},
    {1000270500, 49980910.},
    {1000280500, 49994740.},
    {1000170510, 51015540.},
    {1000180510, 50993700.},
    {1000190510, 50975828.036},
    {1000200510, 50960988.981},
    {1000210510, 50953591.956},
    {1000220510, 50946610.651},
    {1000230510, 50943957.036},
    {1000240510, 50944765.018},
    {1000250510, 50948208.475},
    {1000260510, 50956841.021},
    {1000270510, 50970647.000},
    {1000280510, 50986110.},
    {1000180520, 51998960.},
    {1000190520, 51982240.},
    {1000200520, 51963217.145},
    {1000210520, 51956879.479},
    {1000220520, 51946893.006},
    {1000230520, 51944773.007},
    {1000240520, 51940506.231},
    {1000250520, 51945563.949},
    {1000260520, 51948113.146},
    {1000270520, 51963510.},
    {1000280520, 51974800.},
    {1000290520, 51996710.},
    {1000180530, 53007290.},
    {1000190530, 52987460.},
    {1000200530, 52969450.},
    {1000210530, 52959090.000},
    {1000220530, 52949725.933},
    {1000230530, 52944336.741},
    {1000240530, 52940648.147},
    {1000250530, 52941288.891},
    {1000260530, 52945306.428},
    {1000270530, 52954204.077},
    {1000280530, 52968190.000},
    {1000290530, 52984590.},
    {1000190540, 53994630.},
    {1000200540, 53973400.},
    {1000210540, 53963930.000},
    {1000220540, 53951049.547},
    {1000230540, 53946438.617},
    {1000240540, 53938879.158},
    {1000250540, 53940357.615},
    {1000260540, 53939608.986},
    {1000270540, 53948459.872},
    {1000280540, 53957892.463},
    {1000290540, 53976660.},
    {1000300540, 53992039.},
    {1000190550, 55000760.},
    {1000200550, 54980300.},
    {1000210550, 54967818.892},
    {1000220550, 54955268.064},
    {1000230550, 54947242.150},
    {1000240550, 54940838.434},
    {1000250550, 54938043.910},
    {1000260550, 54938291.994},
    {1000270550, 54941997.202},
    {1000280550, 54951330.632},
    {1000290550, 54966038.000},
    {1000300550, 54983980.},
    {1000190560, 56008510.},
    {1000200560, 55985080.},
    {1000210560, 55973450.},
    {1000220560, 55957911.353},
    {1000230560, 55950484.810},
    {1000240560, 55940653.139},
    {1000250560, 55938903.691},
    {1000260560, 55934936.326},
    {1000270560, 55939838.798},
    {1000280560, 55942128.549},
    {1000290560, 55958950.},
    {1000300560, 55972540.},
    {1000310560, 55995360.},
    {1000200570, 56992620.},
    {1000210570, 56977770.},
    {1000220570, 56963641.626},
    {1000230570, 56952518.869},
    {1000240570, 56943613.013},
    {1000250570, 56938286.096},
    {1000260570, 56935392.841},
    {1000270570, 56936290.574},
    {1000280570, 56939792.184},
    {1000290570, 56949212.498},
    {1000300570, 56965060.},
    {1000310570, 56983200.},
    {1000200580, 57997940.},
    {1000210580, 57984030.},
    {1000220580, 57966600.},
    {1000230580, 57956715.235},
    {1000240580, 57944353.129},
    {1000250580, 57940066.645},
    {1000260580, 57933274.431},
    {1000270580, 57935752.073},
    {1000280580, 57935342.414},
    {1000290580, 57944533.046},
    {1000300580, 57954591.062},
    {1000310580, 57974780.},
    {1000320580, 57991720.},
    {1000210590, 58988940.},
    {1000220590, 58972470.},
    {1000230590, 58959385.659},
    {1000240590, 58948586.367},
    {1000250590, 58940391.113},
    {1000260590, 58934874.338},
    {1000270590, 58933194.288},
    {1000280590, 58934346.202},
    {1000290590, 58939497.482},
    {1000300590, 58949312.657},
    {1000310590, 58963530.},
    {1000320590, 58982490.},
    {1000210600, 59995650.},
    {1000220600, 59976030.},
    {1000230600, 59964313.290},
    {1000240600, 59950076.033},
    {1000250600, 59943136.576},
    {1000260600, 59934071.100},
    {1000270600, 59933816.299},
    {1000280600, 59930785.885},
    {1000290600, 59937364.544},
    {1000300600, 59941842.103},
    {1000310600, 59957290.},
    {1000320600, 59970360.},
    {1000330600, 59993880.},
    {1000210610, 61001000.},
    {1000220610, 60982450.},
    {1000230610, 60967250.000},
    {1000240610, 60954422.585},
    {1000250610, 60944452.544},
    {1000260610, 60936746.244},
    {1000270610, 60932476.620},
    {1000280610, 60931055.570},
    {1000290610, 60933457.612},
    {1000300610, 60939507.188},
    {1000310610, 60949398.984},
    {1000320610, 60963790.},
    {1000330610, 60981120.},
    {1000220620, 61986510.},
    {1000230620, 61972650.},
    {1000240620, 61956097.451},
    {1000250620, 61947954.},
    {1000260620, 61936791.812},
    {1000270620, 61934058.809},
    {1000280620, 61928345.365},
    {1000290620, 61932595.415},
    {1000300620, 61934333.971},
    {1000310620, 61944190.251},
    {1000320620, 61955020.},
    {1000330620, 61973610.},
    {1000220630, 62993750.},
    {1000230630, 62976390.},
    {1000240630, 62961650.731},
    {1000250630, 62949664.675},
    {1000260630, 62940272.700},
    {1000270630, 62933600.217},
    {1000280630, 62929669.626},
    {1000290630, 62929597.723},
    {1000300630, 62933211.474},
    {1000310630, 62939294.196},
    {1000320630, 62949628.000},
    {1000330630, 62963900.},
    {1000230640, 63982640.},
    {1000240640, 63964080.},
    {1000250640, 63953849.370},
    {1000260640, 63940987.763},
    {1000270640, 63935810.764},
    {1000280640, 63927966.816},
    {1000290640, 63929764.342},
    {1000300640, 63929142.013},
    {1000310640, 63936840.440},
    {1000320640, 63941689.913},
    {1000330640, 63957432.},
    {1000340640, 63971090.},
    {1000230650, 64987500.},
    {1000240650, 64969960.},
    {1000250650, 64956019.750},
    {1000260650, 64945011.462},
    {1000270650, 64936462.072},
    {1000280650, 64930085.173},
    {1000290650, 64927789.704},
    {1000300650, 64929240.770},
    {1000310650, 64932734.588},
    {1000320650, 64939368.137},
    {1000330650, 64949611.000},
    {1000340650, 64964400.},
    {1000230660, 65993980.},
    {1000240660, 65973660.},
    {1000250660, 65960546.834},
    {1000260660, 65946249.960},
    {1000270660, 65939442.945},
    {1000280660, 65929139.334},
    {1000290660, 65928869.032},
    {1000300660, 65926033.809},
    {1000310660, 65931589.401},
    {1000320660, 65933862.126},
    {1000330660, 65944148.779},
    {1000340660, 65955590.},
    {1000240670, 66980160.},
    {1000250670, 66964240.},
    {1000260670, 66950543.395},
    {1000270670, 66940609.627},
    {1000280670, 66931569.414},
    {1000290670, 66927730.314},
    {1000300670, 66927127.746},
    {1000310670, 66928202.547},
    {1000320670, 66932733.861},
    {1000330670, 66939251.112},
    {1000340670, 66949994.000},
    {1000350670, 66964650.},
    {1000240680, 67984030.},
    {1000250680, 67969620.},
    {1000260680, 67952951.550},
    {1000270680, 67944257.589},
    {1000280680, 67931868.789},
    {1000290680, 67929610.889},
    {1000300680, 67924844.554},
    {1000310680, 67927980.485},
    {1000320680, 67928095.307},
    {1000330680, 67936774.130},
    {1000340680, 67941825.238},
    {1000350680, 67958732.},
    {1000250690, 68973660.},
    {1000260690, 68958070.},
    {1000270690, 68946141.268},
    {1000280690, 68935610.269},
    {1000290690, 68929429.269},
    {1000300690, 68926550.682},
    {1000310690, 68925573.541},
    {1000320690, 68927964.481},
    {1000330690, 68932246.302},
    {1000340690, 68939414.847},
    {1000350690, 68950497.297},
    {1000360690, 68965180.},
    {1000250700, 69979370.},
    {1000260700, 69961020.},
    {1000270700, 69949630.000},
    {1000280700, 69936431.302},
    {1000290700, 69932392.079},
    {1000300700, 69925319.208},
    {1000310700, 69926021.927},
    {1000320700, 69924248.750},
    {1000330700, 69930926.195},
    {1000340700, 69933515.523},
    {1000350700, 69944792.323},
    {1000360700, 69956040.},
    {1000250710, 70983680.},
    {1000260710, 70966720.},
    {1000270710, 70952366.923},
    {1000280710, 70940518.964},
    {1000290710, 70932676.833},
    {1000300710, 70927719.582},
    {1000310710, 70924702.577},
    {1000320710, 70924952.327},
    {1000330710, 70927113.801},
    {1000340710, 70932209.433},
    {1000350710, 70939342.155},
    {1000360710, 70950265.696},
    {1000370710, 70965320.},
    {1000260720, 71969830.},
    {1000270720, 71957290.},
    {1000280720, 71941785.926},
    {1000290720, 71935820.307},
    {1000300720, 71926842.807},
    {1000310720, 71926367.474},
    {1000320720, 71922075.826},
    {1000330720, 71926752.294},
    {1000340720, 71927140.507},
    {1000350720, 71936588.619},
    {1000360720, 71942092.407},
    {1000370720, 71959080.},
    {1000260730, 72975720.},
    {1000270730, 72960390.},
    {1000280730, 72946206.683},
    {1000290730, 72936674.378},
    {1000300730, 72929582.582},
    {1000310730, 72925174.682},
    {1000320730, 72923458.956},
    {1000330730, 72923829.086},
    {1000340730, 72926754.882},
    {1000350730, 72931671.503},
    {1000360730, 72939289.195},
    {1000370730, 72950529.},
    {1000380730, 72965700.},
    {1000260740, 73979350.},
    {1000270740, 73965150.},
    {1000280740, 73947980.},
    {1000290740, 73939874.862},
    {1000300740, 73929407.262},
    {1000310740, 73926945.727},
    {1000320740, 73921177.761},
    {1000330740, 73923928.598},
    {1000340740, 73922475.934},
    {1000350740, 73929910.177},
    {1000360740, 73933084.020},
    {1000370740, 73944265.894},
    {1000380740, 73956170.},
    {1000270750, 74968760.},
    {1000280750, 74952500.},
    {1000290750, 74941522.606},
    {1000300750, 74932840.246},
    {1000310750, 74926500.246},
    {1000320750, 74922858.370},
    {1000330750, 74921594.567},
    {1000340750, 74922522.870},
    {1000350750, 74925810.452},
    {1000360750, 74930945.746},
    {1000370750, 74938573.201},
    {1000380750, 74949952.770},
    {1000270760, 75974130.},
    {1000280760, 75955330.},
    {1000290760, 75945275.026},
    {1000300760, 75933114.957},
    {1000310760, 75928827.626},
    {1000320760, 75921402.726},
    {1000330760, 75922392.015},
    {1000340760, 75919213.704},
    {1000350760, 75924541.576},
    {1000360760, 75925910.271},
    {1000370760, 75935073.032},
    {1000380760, 75941762.761},
    {1000390760, 75958560.},
    {1000280770, 76960550.},
    {1000290770, 76947920.},
    {1000300770, 76936887.199},
    {1000310770, 76929154.300},
    {1000320770, 76923549.843},
    {1000330770, 76920647.563},
    {1000340770, 76919914.154},
    {1000350770, 76921379.198},
    {1000360770, 76924670.000},
    {1000370770, 76930401.600},
    {1000380770, 76937945.455},
    {1000390770, 76949781.},
    {1000280780, 77963360.},
    {1000290780, 77952230.000},
    {1000300780, 77938289.206},
    {1000310780, 77931608.845},
    {1000320780, 77922852.908},
    {1000330780, 77921827.773},
    {1000340780, 77917309.280},
    {1000350780, 77921145.895},
    {1000360780, 77920364.944},
    {1000370780, 77928141.868},
    {1000380780, 77932179.980},
    {1000390780, 77943610.},
    {1000400780, 77955660.},
    {1000280790, 78970252.},
    {1000290790, 78955020.},
    {1000300790, 78942638.069},
    {1000310790, 78932852.301},
    {1000320790, 78925360.127},
    {1000330790, 78920948.423},
    {1000340790, 78918499.287},
    {1000350790, 78918337.579},
    {1000360790, 78920082.923},
    {1000370790, 78923989.864},
    {1000380790, 78929707.664},
    {1000390790, 78937351.299},
    {1000400790, 78949480.},
    {1000290800, 79960890.},
    {1000300800, 79944552.931},
    {1000310800, 79936420.775},
    {1000320800, 79925350.775},
    {1000330800, 79922474.584},
    {1000340800, 79916521.762},
    {1000350800, 79918529.788},
    {1000360800, 79916378.084},
    {1000370800, 79922516.444},
    {1000380800, 79924517.516},
    {1000390800, 79934356.096},
    {1000400800, 79940400.000},
    {1000290810, 80965872.},
    {1000300810, 80950402.619},
    {1000310810, 80938133.843},
    {1000320810, 80928832.943},
    {1000330810, 80922132.280},
    {1000340810, 80917993.023},
    {1000350810, 80916289.690},
    {1000360810, 80916591.181},
    {1000370810, 80918993.936},
    {1000380810, 80923211.395},
    {1000390810, 80929455.556},
    {1000400810, 80937308.892},
    {1000410810, 80949600.},
    {1000290820, 81972442.},
    {1000300820, 81954260.},
    {1000310820, 81943176.533},
    {1000320820, 81929774.033},
    {1000330820, 81924741.233},
    {1000340820, 81916699.497},
    {1000350820, 81916803.246},
    {1000360820, 81913482.730},
    {1000370820, 81918209.024},
    {1000380820, 81918399.855},
    {1000390820, 81926931.401},
    {1000400820, 81931354.},
    {1000410820, 81943960.},
    {1000300830, 82960560.},
    {1000310830, 82947120.301},
    {1000320830, 82934539.101},
    {1000330830, 82925206.901},
    {1000340830, 82919118.569},
    {1000350830, 82915175.620},
    {1000360830, 82914127.164},
    {1000370830, 82915114.183},
    {1000380830, 82917554.374},
    {1000390830, 82922485.250},
    {1000400830, 82929242.150},
    {1000410830, 82937293.731},
    {1000420830, 82949880.},
    {1000300840, 83965206.},
    {1000310840, 83952460.},
    {1000320840, 83937575.092},
    {1000330840, 83929303.292},
    {1000340840, 83918466.763},
    {1000350840, 83916496.419},
    {1000360840, 83911497.72816},
    {1000370840, 83914375.229},
    {1000380840, 83913419.136},
    {1000390840, 83920672.086},
    {1000400840, 83923326.899},
    {1000410840, 83934492.},
    {1000420840, 83941490.},
    {1000300850, 84972260.},
    {1000310850, 84956990.},
    {1000320850, 84942969.660},
    {1000330850, 84932163.660},
    {1000340850, 84922260.760},
    {1000350850, 84915645.760},
    {1000360850, 84912527.262},
    {1000370850, 84911789.73790},
    {1000380850, 84912932.046},
    {1000390850, 84916433.039},
    {1000400850, 84921444.448},
    {1000410850, 84928845.837},
    {1000420850, 84938260.737},
    {1000430850, 84950580.},
    {1000310860, 85963010.},
    {1000320860, 85946580.},
    {1000330860, 85936701.533},
    {1000340860, 85924311.733},
    {1000350860, 85918805.433},
    {1000360860, 85910610.62693},
    {1000370860, 85911167.425},
    {1000380860, 85909260.608},
    {1000390860, 85914885.980},
    {1000400860, 85916297.204},
    {1000410860, 85925782.798},
    {1000420860, 85931174.817},
    {1000430860, 85944930.},
    {1000310870, 86968245.},
    {1000320870, 86952680.},
    {1000330870, 86940291.718},
    {1000340870, 86928688.618},
    {1000350870, 86920674.018},
    {1000360870, 86913354.760},
    {1000370870, 86909180.531},
    {1000380870, 86908877.531},
    {1000390870, 86910876.138},
    {1000400870, 86914817.988},
    {1000410870, 86920693.747},
    {1000420870, 86928196.201},
    {1000430870, 86938067.187},
    {1000440870, 86950690.},
    {1000320880, 87956910.},
    {1000330880, 87945550.},
    {1000340880, 87931417.492},
    {1000350880, 87924083.292},
    {1000360880, 87914447.881},
    {1000370880, 87911315.592},
    {1000380880, 87905612.542},
    {1000390880, 87909501.563},
    {1000400880, 87910221.290},
    {1000410880, 87918221.710},
    {1000420880, 87921967.781},
    {1000430880, 87933782.381},
    {1000440880, 87941600.},
    {1000320890, 88963790.},
    {1000330890, 88949760.},
    {1000340890, 88936669.060},
    {1000350890, 88926704.560},
    {1000360890, 88917835.451},
    {1000370890, 88912278.298},
    {1000380890, 88907451.095},
    {1000390890, 88905840.348},
    {1000400890, 88908881.441},
    {1000410890, 88913445.073},
    {1000420890, 88919468.151},
    {1000430890, 88927648.651},
    {1000440890, 88937620.},
    {1000450890, 88950584.},
    {1000320900, 89968630.},
    {1000330900, 89955630.},
    {1000340900, 89940096.000},
    {1000350900, 89931292.850},
    {1000360900, 89919527.931},
    {1000370900, 89914798.453},
    {1000380900, 89907730.037},
    {1000390900, 89907143.942},
    {1000400900, 89904697.659},
    {1000410900, 89911258.449},
    {1000420900, 89913930.861},
    {1000430900, 89924073.921},
    {1000440900, 89930344.380},
    {1000450900, 89944220.},
    {1000330910, 90960390.},
    {1000340910, 90945960.},
    {1000350910, 90934398.619},
    {1000360910, 90923806.311},
    {1000370910, 90916537.169},
    {1000380910, 90910195.442},
    {1000390910, 90907297.442},
    {1000400910, 90905639.587},
    {1000410910, 90906989.658},
    {1000420910, 90911745.312},
    {1000430910, 90918425.397},
    {1000440910, 90926741.859},
    {1000450910, 90936880.},
    {1000460910, 90950320.},
    {1000330920, 91966740.},
    {1000340920, 91949840.},
    {1000350920, 91939631.597},
    {1000360920, 91926173.094},
    {1000370920, 91919728.389},
    {1000380920, 91911038.190},
    {1000390920, 91908945.142},
    {1000400920, 91905034.675},
    {1000410920, 91907188.081},
    {1000420920, 91906807.959},
    {1000430920, 91915269.779},
    {1000440920, 91920234.375},
    {1000450920, 91932367.694},
    {1000460920, 91940880.},
    {1000340930, 92956290.},
    {1000350930, 92943134.000},
    {1000360930, 92931147.174},
    {1000370930, 92922039.269},
    {1000380930, 92914024.228},
    {1000390930, 92909577.886},
    {1000400930, 92906469.947},
    {1000410930, 92906373.004},
    {1000420930, 92906809.577},
    {1000430930, 92910245.952},
    {1000440930, 92917104.444},
    {1000450930, 92925912.781},
    {1000460930, 92936511.},
    {1000470930, 92950330.},
    {1000340940, 93960490.},
    {1000350940, 93948900.},
    {1000360940, 93934140.454},
    {1000370940, 93926394.814},
    {1000380940, 93915355.602},
    {1000390940, 93911590.582},
    {1000400940, 93906310.828},
    {1000410940, 93907278.836},
    {1000420940, 93905084.903},
    {1000430940, 93909653.637},
    {1000440940, 93911342.863},
    {1000450940, 93921730.453},
    {1000460940, 93929037.603},
    {1000470940, 93943734.},
    {1000340950, 94967300.},
    {1000350950, 94953010.},
    {1000360950, 94939710.924},
    {1000370950, 94929260.004},
    {1000380950, 94919352.941},
    {1000390950, 94912816.058},
    {1000400950, 94908038.530},
    {1000410950, 94906832.404},
    {1000420950, 94905838.766},
    {1000430950, 94907653.612},
    {1000440950, 94910405.759},
    {1000450950, 94915897.895},
    {1000460950, 94924889.838},
    {1000470950, 94936020.},
    {1000480950, 94949940.},
    {1000350960, 95959030.},
    {1000360960, 95943016.618},
    {1000370960, 95934133.380},
    {1000380960, 95921706.575},
    {1000390960, 95915896.835},
    {1000400960, 95908271.433},
    {1000410960, 95908097.286},
    {1000420960, 95904676.115},
    {1000430960, 95907868.022},
    {1000440960, 95907590.255},
    {1000450960, 95914453.051},
    {1000460960, 95918215.084},
    {1000470960, 95930743.906},
    {1000480960, 95940340.},
    {1000350970, 96963440.},
    {1000360970, 96949088.785},
    {1000370970, 96937177.136},
    {1000380970, 96926373.960},
    {1000390970, 96918274.106},
    {1000400970, 96910951.206},
    {1000410970, 96908095.932},
    {1000420970, 96906018.118},
    {1000430970, 96906366.706},
    {1000440970, 96907547.120},
    {1000450970, 96911329.216},
    {1000460970, 96916471.988},
    {1000470970, 96923965.326},
    {1000480970, 96935100.},
    {1000490970, 96949340.},
    {1000350980, 97969460.},
    {1000360980, 97952430.},
    {1000370980, 97941686.868},
    {1000380980, 97928688.778},
    {1000390980, 97922382.119},
    {1000400980, 97912728.892},
    {1000410980, 97910326.459},
    {1000420980, 97905404.820},
    {1000430980, 97907212.365},
    {1000440980, 97905286.813},
    {1000450980, 97910707.839},
    {1000460980, 97912698.337},
    {1000470980, 97921559.973},
    {1000480980, 97927389.318},
    {1000490980, 97942140.},
    {1000360990, 98958390.},
    {1000370990, 98945028.735},
    {1000380990, 98932890.666},
    {1000390990, 98924147.979},
    {1000400990, 98916666.746},
    {1000410990, 98911613.177},
    {1000420990, 98907708.509},
    {1000430990, 98906250.844},
    {1000440990, 98905934.082},
    {1000450990, 98908128.239},
    {1000460990, 98911774.806},
    {1000470990, 98917645.768},
    {1000480990, 98924925.848},
    {1000490990, 98934110.},
    {1000500990, 98948530.},
    {1000361000, 99962370.},
    {1000371000, 99950030.},
    {1000381000, 99935769.692},
    {1000391000, 99927714.692},
    {1000401000, 99918000.576},
    {1000411000, 99914327.592},
    {1000421000, 99907471.782},
    {1000431000, 99907653.877},
    {1000441000, 99904214.256},
    {1000451000, 99908117.264},
    {1000461000, 99908504.805},
    {1000471000, 99916115.445},
    {1000481000, 99920348.820},
    {1000491000, 99930957.180},
    {1000501000, 99938504.196},
    {1000361010, 100968730.},
    {1000371010, 100954039.},
    {1000381010, 100940351.743},
    {1000391010, 100930147.705},
    {1000401010, 100921447.964},
    {1000411010, 100915310.254},
    {1000421010, 100910341.447},
    {1000431010, 100907309.057},
    {1000441010, 100905576.872},
    {1000451010, 100906160.613},
    {1000461010, 100908286.412},
    {1000471010, 100912683.953},
    {1000481010, 100918586.211},
    {1000491010, 100926340.},
    {1000501010, 100935259.244},
    {1000371020, 101959520.},
    {1000381020, 101943790.979},
    {1000391020, 101934327.687},
    {1000401020, 101923140.930},
    {1000411020, 101918077.197},
    {1000421020, 101910283.414},
    {1000431020, 101909209.733},
    {1000441020, 101904344.096},
    {1000451020, 101906837.373},
    {1000461020, 101905602.187},
    {1000471020, 101911704.708},
    {1000481020, 101914481.967},
    {1000491020, 101924107.138},
    {1000501020, 101930290.753},
    {1000371030, 102963920.},
    {1000381030, 102949090.},
    {1000391030, 102937243.004},
    {1000401030, 102927190.678},
    {1000411030, 102919457.238},
    {1000421030, 102913078.578},
    {1000431030, 102909176.131},
    {1000441030, 102906318.627},
    {1000451030, 102905497.993},
    {1000461030, 102906080.949},
    {1000471030, 102908963.138},
    {1000481030, 102913416.517},
    {1000491030, 102919881.915},
    {1000501030, 102928105.264},
    {1000511030, 102939690.},
    {1000381040, 103952650.},
    {1000391040, 103941960.},
    {1000401040, 103929435.691},
    {1000411040, 103922892.491},
    {1000421040, 103913734.373},
    {1000431040, 103911424.888},
    {1000441040, 103905427.481},
    {1000451040, 103906649.220},
    {1000461040, 103904030.540},
    {1000471040, 103908623.864},
    {1000481040, 103909856.386},
    {1000491040, 103918214.541},
    {1000501040, 103923105.204},
    {1000511040, 103936477.804},
    {1000381050, 104958550.},
    {1000391050, 104945440.},
    {1000401050, 104934008.204},
    {1000411050, 104924946.471},
    {1000421050, 104916968.617},
    {1000431050, 104911654.883},
    {1000441050, 104907747.645},
    {1000451050, 104905688.549},
    {1000461050, 104905079.626},
    {1000471050, 104906525.615},
    {1000481050, 104909463.896},
    {1000491050, 104914502.325},
    {1000501050, 104921268.429},
    {1000511050, 104931275.897},
    {1000521050, 104943304.508},
    {1000381060, 105962651.},
    {1000391060, 105950560.},
    {1000401060, 105936760.},
    {1000411060, 105928931.712},
    {1000421060, 105918259.464},
    {1000431060, 105914357.598},
    {1000441060, 105907329.104},
    {1000451060, 105907286.801},
    {1000461060, 105903480.426},
    {1000471060, 105906663.637},
    {1000481060, 105906459.928},
    {1000491060, 105913463.735},
    {1000501060, 105916957.404},
    {1000511060, 105928637.982},
    {1000521060, 105937499.664},
    {1000381070, 106968975.},
    {1000391070, 106954520.},
    {1000401070, 106941740.},
    {1000411070, 106931593.654},
    {1000421070, 106922105.877},
    {1000431070, 106915460.645},
    {1000441070, 106909972.045},
    {1000451070, 106906747.811},
    {1000461070, 106905128.195},
    {1000471070, 106905091.611},
    {1000481070, 106906612.122},
    {1000491070, 106910290.084},
    {1000501070, 106915713.652},
    {1000511070, 106924150.641},
    {1000521070, 106935011.573},
    {1000531070, 106946780.},
    {1000391080, 107959960.},
    {1000401080, 107944870.},
    {1000411080, 107936074.773},
    {1000421080, 107924033.490},
    {1000431080, 107918495.722},
    {1000441080, 107910188.022},
    {1000451080, 107908714.473},
    {1000461080, 107903891.640},
    {1000471080, 107905950.346},
    {1000481080, 107904183.440},
    {1000491080, 107909693.524},
    {1000501080, 107911894.287},
    {1000511080, 107922226.735},
    {1000521080, 107929380.467},
    {1000531080, 107943481.623},
    {1000391090, 108964358.},
    {1000401090, 108950410.},
    {1000411090, 108939216.000},
    {1000421090, 108928424.160},
    {1000431090, 108920256.356},
    {1000441090, 108913325.956},
    {1000451090, 108908748.821},
    {1000461090, 108905950.406},
    {1000471090, 108904755.282},
    {1000481090, 108904986.653},
    {1000491090, 108907151.381},
    {1000501090, 108911292.060},
    {1000511090, 108918141.122},
    {1000521090, 108927304.534},
    {1000531090, 108938085.287},
    {1000541090, 108950434.864},
    {1000401100, 109953960.},
    {1000411100, 109944030.},
    {1000421100, 109930703.673},
    {1000431100, 109923743.534},
    {1000441100, 109914040.696},
    {1000451100, 109911079.429},
    {1000461100, 109905172.199},
    {1000471100, 109906110.226},
    {1000481100, 109903006.606},
    {1000491100, 109907169.810},
    {1000501100, 109907844.835},
    {1000511100, 109916854.287},
    {1000521100, 109922458.091},
    {1000531100, 109935089.034},
    {1000541100, 109944263.102},
    {1000401110, 110959678.},
    {1000411110, 110947530.},
    {1000421110, 110935654.257},
    {1000431110, 110925901.257},
    {1000441110, 110917569.857},
    {1000451110, 110911642.310},
    {1000461110, 110907689.679},
    {1000471110, 110905295.923},
    {1000481110, 110904182.872},
    {1000491110, 110905108.458},
    {1000501110, 110907740.127},
    {1000511110, 110913218.189},
    {1000521110, 110921000.589},
    {1000531110, 110930269.214},
    {1000541110, 110941607.206},
    {1000401120, 111963703.},
    {1000411120, 111952470.},
    {1000421120, 111938310.},
    {1000431120, 111929945.813},
    {1000441120, 111918809.234},
    {1000451120, 111914403.222},
    {1000461120, 111907329.698},
    {1000471120, 111907048.550},
    {1000481120, 111902762.868},
    {1000491120, 111905537.694},
    {1000501120, 111904823.874},
    {1000511120, 111912399.903},
    {1000521120, 111916727.850},
    {1000531120, 111928004.550},
    {1000541120, 111935558.982},
    {1000551120, 111950308.558},
    {1000411130, 112956510.},
    {1000421130, 112943350.},
    {1000431130, 112932569.035},
    {1000441130, 112922843.999},
    {1000451130, 112915439.342},
    {1000461130, 112910261.042},
    {1000471130, 112906572.893},
    {1000481130, 112904408.133},
    {1000491130, 112904061.839},
    {1000501130, 112905175.728},
    {1000511130, 112909374.536},
    {1000521130, 112915891.000},
    {1000531130, 112923650.064},
    {1000541130, 112933221.650},
    {1000551130, 112944429.144},
    {1000411140, 113962010.},
    {1000421140, 113946530.},
    {1000431140, 113936910.},
    {1000441140, 113924613.554},
    {1000451140, 113918718.294},
    {1000461140, 113910368.554},
    {1000471140, 113908823.031},
    {1000481140, 113903365.086},
    {1000491140, 113904917.909},
    {1000501140, 113902782.695},
    {1000511140, 113909290.189},
    {1000521140, 113912089.000},
    {1000531140, 113921850.},
    {1000541140, 113927980.331},
    {1000551140, 113941296.176},
    {1000561140, 113950660.438},
    {1000411150, 114966340.},
    {1000421150, 114951960.},
    {1000431150, 114939980.},
    {1000441150, 114928819.898},
    {1000451150, 114920311.589},
    {1000461150, 114913658.506},
    {1000471150, 114908767.355},
    {1000481150, 114905437.513},
    {1000491150, 114903878.776},
    {1000501150, 114903344.699},
    {1000511150, 114906598.000},
    {1000521150, 114911902.000},
    {1000531150, 114918048.000},
    {1000541150, 114926293.945},
    {1000551150, 114935910.},
    {1000561150, 114947370.},
    {1000421160, 115955448.},
    {1000431160, 115944760.},
    {1000441160, 115931219.195},
    {1000451160, 115924058.528},
    {1000461160, 115914296.979},
    {1000471160, 115911386.812},
    {1000481160, 115904763.148},
    {1000491160, 115905259.995},
    {1000501160, 115901742.797},
    {1000511160, 115906793.115},
    {1000521160, 115908460.000},
    {1000531160, 115916808.658},
    {1000541160, 115921581.112},
    {1000551160, 115933373.},
    {1000561160, 115941280.},
    {1000571160, 115956304.},
    {1000421170, 116961170.},
    {1000431170, 116948060.},
    {1000441170, 116936103.000},
    {1000451170, 116926035.391},
    {1000461170, 116917954.721},
    {1000471170, 116911773.934},
    {1000481170, 116907225.956},
    {1000491170, 116904515.678},
    {1000501170, 116902953.983},
    {1000511170, 116904841.508},
    {1000521170, 116908646.298},
    {1000531170, 116913648.312},
    {1000541170, 116920358.761},
    {1000551170, 116928616.726},
    {1000561170, 116938140.570},
    {1000571170, 116949985.},
    {1000431180, 117952990.},
    {1000441180, 117938530.},
    {1000451180, 117930340.208},
    {1000461180, 117919066.700},
    {1000471180, 117914595.487},
    {1000481180, 117906921.869},
    {1000491180, 117906356.616},
    {1000501180, 117901606.574},
    {1000511180, 117905532.139},
    {1000521180, 117905853.629},
    {1000531180, 117913074.000},
    {1000541180, 117916178.680},
    {1000551180, 117926559.519},
    {1000561180, 117933060.},
    {1000571180, 117946730.},
    {1000431190, 118956660.},
    {1000441190, 118943570.},
    {1000451190, 118932556.954},
    {1000461190, 118923340.223},
    {1000471190, 118915570.287},
    {1000481190, 118909846.851},
    {1000491190, 118905850.708},
    {1000501190, 118903311.172},
    {1000511190, 118903945.471},
    {1000521190, 118906407.108},
    {1000531190, 118910074.000},
    {1000541190, 118915410.714},
    {1000551190, 118922377.330},
    {1000561190, 118930659.686},
    {1000571190, 118940990.},
    {1000581190, 118952710.},
    {1000431200, 119961870.},
    {1000441200, 119946310.},
    {1000451200, 119936860.},
    {1000461200, 119924551.089},
    {1000471200, 119918784.768},
    {1000481200, 119909868.068},
    {1000491200, 119907966.567},
    {1000501200, 119902201.634},
    {1000511200, 119905079.385},
    {1000521200, 119904059.300},
    {1000531200, 119910087.251},
    {1000541200, 119911784.270},
    {1000551200, 119920677.279},
    {1000561200, 119926045.000},
    {1000571200, 119938070.},
    {1000581200, 119946540.},
    {1000441210, 120951640.},
    {1000451210, 120939420.},
    {1000461210, 120928950.345},
    {1000471210, 120920125.282},
    {1000481210, 120912963.663},
    {1000491210, 120907851.062},
    {1000501210, 120904242.554},
    {1000511210, 120903811.967},
    {1000521210, 120904943.812},
    {1000531210, 120907405.050},
    {1000541210, 120911453.015},
    {1000551210, 120917227.238},
    {1000561210, 120924052.290},
    {1000571210, 120933150.},
    {1000581210, 120943350.},
    {1000591210, 120955320.},
    {1000441220, 121954470.},
    {1000451220, 121943990.},
    {1000461220, 121930631.696},
    {1000471220, 121923664.449},
    {1000481220, 121913459.053},
    {1000491220, 121910280.738},
    {1000501220, 121903443.774},
    {1000511220, 121905169.948},
    {1000521220, 121903043.455},
    {1000531220, 121907588.841},
    {1000541220, 121908367.658},
    {1000551220, 121916108.146},
    {1000561220, 121919904.000},
    {1000571220, 121930710.},
    {1000581220, 121937870.},
    {1000591220, 121951750.},
    {1000441230, 122959890.},
    {1000451230, 122946850.},
    {1000461230, 122935140.},
    {1000471230, 122925337.063},
    {1000481230, 122916892.453},
    {1000491230, 122910433.718},
    {1000501230, 122905725.221},
    {1000511230, 122904213.204},
    {1000521230, 122904269.769},
    {1000531230, 122905588.537},
    {1000541230, 122908481.757},
    {1000551230, 122912996.063},
    {1000561230, 122918781.063},
    {1000571230, 122926300.},
    {1000581230, 122935280.},
    {1000591230, 122945960.},
    {1000441240, 123963050.},
    {1000451240, 123951510.},
    {1000461240, 123937140.},
    {1000471240, 123928931.229},
    {1000481240, 123917657.364},
    {1000491240, 123913182.245},
    {1000501240, 123905276.645},
    {1000511240, 123905934.978},
    {1000521240, 123902817.085},
    {1000531240, 123906209.041},
    {1000541240, 123905891.984},
    {1000551240, 123912257.798},
    {1000561240, 123915093.629},
    {1000571240, 123924574.275},
    {1000581240, 123930310.},
    {1000591240, 123942940.},
    {1000601240, 123952200.},
    {1000451250, 124954690.},
    {1000461250, 124941790.},
    {1000471250, 124931046.000},
    {1000481250, 124921257.577},
    {1000491250, 124913604.553},
    {1000501250, 124907786.395},
    {1000511250, 124905253.007},
    {1000521250, 124904429.920},
    {1000531250, 124904629.353},
    {1000541250, 124906394.445},
    {1000551250, 124909727.985},
    {1000561250, 124914471.843},
    {1000571250, 124920815.932},
    {1000581250, 124928440.},
    {1000591250, 124937700.},
    {1000601250, 124948900.},
    {1000451260, 125959460.},
    {1000461260, 125944160.},
    {1000471260, 125934750.},
    {1000481260, 125922429.128},
    {1000491260, 125916507.322},
    {1000501260, 125907658.786},
    {1000511260, 125907252.987},
    {1000521260, 125903310.886},
    {1000531260, 125905623.329},
    {1000541260, 125904298.292},
    {1000551260, 125909446.057},
    {1000561260, 125911250.204},
    {1000571260, 125919512.667},
    {1000581260, 125923971.000},
    {1000591260, 125935240.},
    {1000601260, 125943110.},
    {1000611260, 125957920.},
    {1000461270, 126949070.},
    {1000471270, 126937110.},
    {1000481270, 126926472.404},
    {1000491270, 126917446.276},
    {1000501270, 126910389.943},
    {1000511270, 126906924.278},
    {1000521270, 126905225.735},
    {1000531270, 126904471.853},
    {1000541270, 126905182.914},
    {1000551270, 126907417.384},
    {1000561270, 126911091.275},
    {1000571270, 126916375.084},
    {1000581270, 126922727.000},
    {1000591270, 126930710.},
    {1000601270, 126940380.},
    {1000611270, 126951920.},
    {1000461280, 127951830.},
    {1000471280, 127941060.},
    {1000481280, 127927812.858},
    {1000491280, 127920401.044},
    {1000501280, 127910507.184},
    {1000511280, 127909145.628},
    {1000521280, 127904461.279},
    {1000531280, 127905808.615},
    {1000541280, 127903531.018},
    {1000551280, 127907748.666},
    {1000561280, 127908341.967},
    {1000571280, 127915592.123},
    {1000581280, 127918911.000},
    {1000591280, 127928791.000},
    {1000601280, 127935250.},
    {1000611280, 127948700.},
    {1000621280, 127958420.},
    {1000471290, 128943950.},
    {1000481290, 128931820.},
    {1000491290, 128921805.301},
    {1000501290, 128913464.711},
    {1000511290, 128909146.665},
    {1000521290, 128906596.460},
    {1000531290, 128904983.669},
    {1000541290, 128904780.86113},
    {1000551290, 128906065.683},
    {1000561290, 128908680.798},
    {1000571290, 128912694.431},
    {1000581290, 128918102.000},
    {1000591290, 128925095.000},
    {1000601290, 128933102.},
    {1000611290, 128943230.},
    {1000621290, 128954760.},
    {1000471300, 129950703.},
    {1000481300, 129933940.679},
    {1000491300, 129924976.585},
    {1000501300, 129913973.830},
    {1000511300, 129911662.054},
    {1000521300, 129906222.748},
    {1000531300, 129906670.193},
    {1000541300, 129903509.349},
    {1000551300, 129906709.283},
    {1000561300, 129906320.669},
    {1000571300, 129912369.413},
    {1000581300, 129914736.000},
    {1000591300, 129923590.000},
    {1000601300, 129928506.000},
    {1000611300, 129940530.},
    {1000621300, 129949000.},
    {1000631300, 129963689.},
    {1000481310, 130940600.},
    {1000491310, 130926971.529},
    {1000501310, 130917044.954},
    {1000511310, 130911988.799},
    {1000521310, 130908522.213},
    {1000531310, 130906126.305},
    {1000541310, 130905084.057},
    {1000551310, 130905464.899},
    {1000561310, 130906940.977},
    {1000571310, 130910070.000},
    {1000581310, 130914429.465},
    {1000591310, 130920234.960},
    {1000601310, 130927248.020},
    {1000611310, 130935670.},
    {1000621310, 130946180.},
    {1000631310, 130957842.},
    {1000481320, 131946040.},
    {1000491320, 131933001.273},
    {1000501320, 131917826.725},
    {1000511320, 131914507.691},
    {1000521320, 131908546.716},
    {1000531320, 131907993.514},
    {1000541320, 131904155.08563},
    {1000551320, 131906433.914},
    {1000561320, 131905061.128},
    {1000571320, 131910118.979},
    {1000581320, 131911463.775},
    {1000591320, 131919255.000},
    {1000601320, 131923321.237},
    {1000611320, 131933840.},
    {1000621320, 131940870.},
    {1000631320, 131954670.},
    {1000481330, 132952850.},
    {1000491330, 132938310.},
    {1000501330, 132923913.404},
    {1000511330, 132915273.198},
    {1000521330, 132910968.766},
    {1000531330, 132907796.968},
    {1000541330, 132905910.751},
    {1000551330, 132905451.961},
    {1000561330, 132906007.351},
    {1000571330, 132908218.000},
    {1000581330, 132911520.402},
    {1000591330, 132916330.561},
    {1000601330, 132922348.000},
    {1000611330, 132929782.000},
    {1000621330, 132938560.},
    {1000631330, 132949290.},
    {1000641330, 132961330.},
    {1000491340, 133944540.},
    {1000501340, 133928682.064},
    {1000511340, 133920535.676},
    {1000521340, 133911393.959},
    {1000531340, 133909758.836},
    {1000541340, 133905394.664},
    {1000551340, 133906718.503},
    {1000561340, 133904508.182},
    {1000571340, 133908514.011},
    {1000581340, 133908928.142},
    {1000591340, 133915696.729},
    {1000601340, 133918790.210},
    {1000611340, 133928353.000},
    {1000621340, 133934110.},
    {1000631340, 133946400.},
    {1000641340, 133955660.},
    {1000491350, 134950050.},
    {1000501350, 134934908.606},
    {1000511350, 134925185.106},
    {1000521350, 134916555.706},
    {1000531350, 134910048.847},
    {1000541350, 134907227.780},
    {1000551350, 134905977.049},
    {1000561350, 134905688.375},
    {1000571350, 134906984.363},
    {1000581350, 134909160.599},
    {1000591350, 134913111.775},
    {1000601350, 134918181.321},
    {1000611350, 134924823.000},
    {1000621350, 134932520.000},
    {1000631350, 134941870.},
    {1000641350, 134952450.},
    {1000651350, 134964760.},
    {1000501360, 135939990.},
    {1000511360, 135930745.879},
    {1000521360, 135920100.608},
    {1000531360, 135914604.412},
    {1000541360, 135907214.484},
    {1000551360, 135907311.358},
    {1000561360, 135904575.727},
    {1000571360, 135907634.962},
    {1000581360, 135907129.205},
    {1000591360, 135912677.456},
    {1000601360, 135914976.064},
    {1000611360, 135923584.586},
    {1000621360, 135928275.556},
    {1000631360, 135939620.},
    {1000641360, 135947300.},
    {1000651360, 135961290.},
    {1000501370, 136946550.},
    {1000511370, 136935555.000},
    {1000521370, 136925598.852},
    {1000531370, 136918028.188},
    {1000541370, 136911557.781},
    {1000551370, 136907089.231},
    {1000561370, 136905827.141},
    {1000571370, 136906450.385},
    {1000581370, 136907762.364},
    {1000591370, 136910679.150},
    {1000601370, 136914562.448},
    {1000611370, 136920479.523},
    {1000621370, 136926970.517},
    {1000631370, 136935460.},
    {1000641370, 136945020.},
    {1000651370, 136956020.},
    {1000501380, 137951840.},
    {1000511380, 137941450.},
    {1000521380, 137929472.226},
    {1000531380, 137922726.402},
    {1000541380, 137914146.273},
    {1000551380, 137911017.089},
    {1000561380, 137905246.995},
    {1000571380, 137907114.919},
    {1000581380, 137905991.089},
    {1000591380, 137910754.405},
    {1000601380, 137911949.718},
    {1000611380, 137919548.077},
    {1000621380, 137923243.991},
    {1000631380, 137933709.000},
    {1000641380, 137940250.},
    {1000651380, 137953120.},
    {1000661380, 137962500.},
    {1000511390, 138946550.},
    {1000521390, 138935367.194},
    {1000531390, 138926506.206},
    {1000541390, 138918792.203},
    {1000551390, 138913363.758},
    {1000561390, 138908841.099},
    {1000571390, 138906356.256},
    {1000581390, 138906655.111},
    {1000591390, 138908940.762},
    {1000601390, 138911953.649},
    {1000611390, 138916799.670},
    {1000621390, 138922296.635},
    {1000631390, 138929792.310},
    {1000641390, 138938130.},
    {1000651390, 138948330.},
    {1000661390, 138959590.},
    {1000511400, 139952830.},
    {1000521400, 139939498.567},
    {1000531400, 139931727.000},
    {1000541400, 139921645.817},
    {1000551400, 139917283.063},
    {1000561400, 139910605.730},
    {1000571400, 139909480.635},
    {1000581400, 139905443.107},
    {1000591400, 139909080.275},
    {1000601400, 139909549.849},
    {1000611400, 139916039.639},
    {1000621400, 139918994.717},
    {1000631400, 139928087.637},
    {1000641400, 139933674.000},
    {1000651400, 139945805.049},
    {1000661400, 139954020.},
    {1000671400, 139968589.},
    {1000521410, 140945800.},
    {1000531410, 140935690.},
    {1000541410, 140926787.184},
    {1000551410, 140920045.491},
    {1000561410, 140914403.333},
    {1000571410, 140910966.030},
    {1000581410, 140908280.674},
    {1000591410, 140907657.568},
    {1000601410, 140909614.653},
    {1000611410, 140913555.084},
    {1000621410, 140918481.636},
    {1000631410, 140924931.754},
    {1000641410, 140932126.000},
    {1000651410, 140941448.000},
    {1000661410, 140951280.},
    {1000671410, 140963108.},
    {1000521420, 141950220.},
    {1000531420, 141941202.000},
    {1000541420, 141929973.098},
    {1000551420, 141924295.991},
    {1000561420, 141916432.382},
    {1000571420, 141914090.890},
    {1000581420, 141909250.375},
    {1000591420, 141910049.607},
    {1000601420, 141907728.996},
    {1000611420, 141912890.411},
    {1000621420, 141915204.385},
    {1000631420, 141923441.690},
    {1000641420, 141928116.000},
    {1000651420, 141939280.859},
    {1000661420, 141946194.},
    {1000671420, 141960010.},
    {1000681420, 141970100.},
    {1000521430, 142956760.},
    {1000531430, 142945650.},
    {1000541430, 142935369.554},
    {1000551430, 142927349.327},
    {1000561430, 142920625.293},
    {1000571430, 142916079.512},
    {1000581430, 142912392.120},
    {1000591430, 142910822.796},
    {1000601430, 142909819.989},
    {1000611430, 142910938.262},
    {1000621430, 142914635.303},
    {1000631430, 142920298.681},
    {1000641430, 142926750.682},
    {1000651430, 142935137.335},
    {1000661430, 142943994.335},
    {1000671430, 142954860.},
    {1000681430, 142966620.},
    {1000531440, 143951390.},
    {1000541440, 143938945.079},
    {1000551440, 143932076.313},
    {1000561440, 143922954.866},
    {1000571440, 143919645.589},
    {1000581440, 143913652.939},
    {1000591440, 143913310.859},
    {1000601440, 143910092.974},
    {1000611440, 143912596.396},
    {1000621440, 143912006.466},
    {1000631440, 143918819.553},
    {1000641440, 143922963.000},
    {1000651440, 143933045.000},
    {1000661440, 143939269.515},
    {1000671440, 143952109.715},
    {1000681440, 143960700.},
    {1000691440, 143976283.},
    {1000531450, 144956050.},
    {1000541450, 144944719.634},
    {1000551450, 144935527.435},
    {1000561450, 144927518.400},
    {1000571450, 144921808.068},
    {1000581450, 144917265.228},
    {1000591450, 144914518.156},
    {1000601450, 144912579.322},
    {1000611450, 144912755.935},
    {1000621450, 144913417.339},
    {1000631450, 144916272.629},
    {1000641450, 144921712.821},
    {1000651450, 144928821.947},
    {1000661450, 144937473.995},
    {1000671450, 144947267.395},
    {1000681450, 144958050.},
    {1000691450, 144970389.},
    {1000541460, 145948518.249},
    {1000551460, 145940344.271},
    {1000561460, 145930283.712},
    {1000571460, 145925875.174},
    {1000581460, 145918802.412},
    {1000591460, 145917679.850},
    {1000601460, 145913122.628},
    {1000611460, 145914702.396},
    {1000621460, 145913046.991},
    {1000631460, 145917211.039},
    {1000641460, 145918318.817},
    {1000651460, 145927252.984},
    {1000661460, 145932844.530},
    {1000671460, 145944993.506},
    {1000681460, 145952418.360},
    {1000691460, 145966837.},
    {1000541470, 146954260.},
    {1000551470, 146944156.156},
    {1000561470, 146935303.900},
    {1000571470, 146928417.800},
    {1000581470, 146922689.913},
    {1000591470, 146919007.518},
    {1000601470, 146916106.136},
    {1000611470, 146915144.988},
    {1000621470, 146914904.435},
    {1000631470, 146916752.659},
    {1000641470, 146919101.384},
    {1000651470, 146924054.788},
    {1000661470, 146931082.715},
    {1000671470, 146940142.296},
    {1000681470, 146949964.459},
    {1000691470, 146961379.891},
    {1000541480, 147958130.},
    {1000551480, 147949225.137},
    {1000561480, 147938170.578},
    {1000571480, 147932679.400},
    {1000581480, 147924424.225},
    {1000591480, 147922130.083},
    {1000601480, 147916899.294},
    {1000611480, 147917481.945},
    {1000621480, 147914829.226},
    {1000631480, 147918089.243},
    {1000641480, 147918121.511},
    {1000651480, 147924281.552},
    {1000661480, 147927156.571},
    {1000671480, 147937743.928},
    {1000681480, 147944735.029},
    {1000691480, 147958384.029},
    {1000701480, 147967580.},
    {1000551490, 148953020.},
    {1000561490, 148943080.},
    {1000571490, 148935351.260},
    {1000581490, 148928426.900},
    {1000591490, 148923736.100},
    {1000601490, 148920154.849},
    {1000611490, 148918342.277},
    {1000621490, 148917192.062},
    {1000631490, 148917937.763},
    {1000641490, 148919348.117},
    {1000651490, 148923253.549},
    {1000661490, 148927321.692},
    {1000671490, 148933802.646},
    {1000681490, 148942306.000},
    {1000691490, 148952890.},
    {1000701490, 148964360.},
    {1000551500, 149958330.},
    {1000561500, 149946050.},
    {1000571500, 149939470.},
    {1000581500, 149930384.042},
    {1000591500, 149926676.502},
    {1000601500, 149920902.249},
    {1000611500, 149920990.941},
    {1000621500, 149917282.919},
    {1000631500, 149919707.671},
    {1000641500, 149918664.422},
    {1000651500, 149923664.941},
    {1000661500, 149925593.264},
    {1000671500, 149933498.408},
    {1000681500, 149937915.567},
    {1000691500, 149950090.},
    {1000701500, 149958520.},
    {1000711500, 149973548.},
    {1000551510, 150962580.},
    {1000561510, 150951270.},
    {1000571510, 150942320.},
    {1000581510, 150934272.200},
    {1000591510, 150928309.285},
    {1000601510, 150923840.289},
    {1000611510, 150921217.539},
    {1000621510, 150919939.796},
    {1000631510, 150919857.803},
    {1000641510, 150920355.950},
    {1000651510, 150923109.599},
    {1000661510, 150926191.564},
    {1000671510, 150931698.345},
    {1000681510, 150937448.567},
    {1000691510, 150945487.875},
    {1000701510, 150955402.497},
    {1000711510, 150967677.},
    {1000561520, 151954810.},
    {1000571520, 151946820.},
    {1000581520, 151936600.},
    {1000591520, 151931552.900},
    {1000601520, 151924692.216},
    {1000611520, 151923506.181},
    {1000621520, 151919739.721},
    {1000631520, 151921752.184},
    {1000641520, 151919799.494},
    {1000651520, 151924082.936},
    {1000661520, 151924725.286},
    {1000671520, 151931723.623},
    {1000681520, 151935057.085},
    {1000691520, 151944422.000},
    {1000701520, 151950272.700},
    {1000711520, 151964120.},
    {1000561530, 152960360.},
    {1000571530, 152950360.},
    {1000581530, 152940930.},
    {1000591530, 152933903.539},
    {1000601530, 152927717.978},
    {1000611530, 152924156.686},
    {1000621530, 152922104.650},
    {1000631530, 152921238.003},
    {1000641530, 152921758.027},
    {1000651530, 152923442.403},
    {1000661530, 152925772.378},
    {1000671530, 152930206.429},
    {1000681530, 152935080.440},
    {1000691530, 152942040.101},
    {1000701530, 152949320.},
    {1000711530, 152958751.054},
    {1000721530, 152970690.},
    {1000571540, 153955170.},
    {1000581540, 153943800.},
    {1000591540, 153937525.741},
    {1000601540, 153929484.894},
    {1000611540, 153926471.531},
    {1000621540, 153922216.861},
    {1000631540, 153922986.962},
    {1000641540, 153920874.060},
    {1000651540, 153924684.767},
    {1000661540, 153924429.277},
    {1000671540, 153930606.834},
    {1000681540, 153932790.842},
    {1000691540, 153941570.033},
    {1000701540, 153946395.655},
    {1000711540, 153957364.},
    {1000721540, 153964860.},
    {1000571550, 154959010.},
    {1000581550, 154948550.},
    {1000591550, 154940509.281},
    {1000601550, 154933135.691},
    {1000611550, 154928137.048},
    {1000621550, 154924647.748},
    {1000631550, 154922901.107},
    {1000641550, 154922630.473},
    {1000651550, 154923510.547},
    {1000661550, 154925759.086},
    {1000671550, 154929104.049},
    {1000681550, 154933215.911},
    {1000691550, 154939209.660},
    {1000701550, 154945783.132},
    {1000711550, 154954320.600},
    {1000721550, 154963110.},
    {1000731550, 154974245.},
    {1000581560, 155951830.},
    {1000591560, 155944640.},
    {1000601560, 155935078.894},
    {1000611560, 155931117.516},
    {1000621560, 155925536.067},
    {1000631560, 155924760.494},
    {1000641560, 155922131.241},
    {1000651560, 155924755.181},
    {1000661560, 155924284.713},
    {1000671560, 155929706.112},
    {1000681560, 155931067.313},
    {1000691560, 155938991.573},
    {1000701560, 155942824.698},
    {1000711560, 155953032.522},
    {1000721560, 155959347.805},
    {1000731560, 155972030.},
    {1000581570, 156957050.},
    {1000591570, 156947890.},
    {1000601570, 156939386.061},
    {1000611570, 156933121.393},
    {1000621570, 156928418.698},
    {1000631570, 156925433.446},
    {1000641570, 156923968.569},
    {1000651570, 156924033.028},
    {1000661570, 156925470.660},
    {1000671570, 156928254.427},
    {1000681570, 156931948.658},
    {1000691570, 156936944.120},
    {1000701570, 156942645.349},
    {1000711570, 156950126.667},
    {1000721570, 156958236.},
    {1000731570, 156968176.167},
    {1000741570, 156978840.},
    {1000591580, 157952410.},
    {1000601580, 157941970.},
    {1000611580, 157936565.144},
    {1000621580, 157929951.004},
    {1000631580, 157927798.606},
    {1000641580, 157924112.348},
    {1000651580, 157925420.947},
    {1000661580, 157924415.875},
    {1000671580, 157928945.969},
    {1000681580, 157929893.474},
    {1000691580, 157936979.525},
    {1000701580, 157939870.549},
    {1000711580, 157949315.507},
    {1000721580, 157954801.092},
    {1000731580, 157966541.},
    {1000741580, 157974562.},
    {1000591590, 158955890.},
    {1000601590, 158946530.},
    {1000611590, 158939286.502},
    {1000621590, 158933217.226},
    {1000631590, 158929100.067},
    {1000641590, 158926396.969},
    {1000651590, 158925354.710},
    {1000661590, 158925746.958},
    {1000671590, 158927719.703},
    {1000681590, 158930691.810},
    {1000691590, 158934975.000},
    {1000701590, 158940054.623},
    {1000711590, 158946635.615},
    {1000721590, 158953995.669},
    {1000731590, 158963022.556},
    {1000741590, 158972638.},
    {1000751590, 158984179.},
    {1000601600, 159949400.},
    {1000611600, 159943100.},
    {1000621600, 159935335.311},
    {1000631600, 159931850.939},
    {1000641600, 159927062.411},
    {1000651600, 159927175.556},
    {1000661600, 159925204.646},
    {1000671600, 159928736.606},
    {1000681600, 159929077.130},
    {1000691600, 159935263.106},
    {1000701600, 159937557.406},
    {1000711600, 159946033.000},
    {1000721600, 159950690.749},
    {1000731600, 159961487.510},
    {1000741600, 159968462.584},
    {1000751600, 159981823.},
    {1000601610, 160954280.},
    {1000611610, 160946070.},
    {1000621610, 160939160.170},
    {1000631610, 160933664.091},
    {1000641610, 160929677.476},
    {1000651610, 160927577.825},
    {1000661610, 160926940.492},
    {1000671610, 160927861.547},
    {1000681610, 160930004.599},
    {1000691610, 160933549.000},
    {1000701610, 160937907.138},
    {1000711610, 160943572.000},
    {1000721610, 160950278.370},
    {1000731610, 160958452.265},
    {1000741610, 160967197.},
    {1000751610, 160977572.951},
    {1000761610, 160989029.},
    {1000611620, 161950220.},
    {1000621620, 161941460.},
    {1000631620, 161936988.761},
    {1000641620, 161930993.017},
    {1000651620, 161929495.360},
    {1000661620, 161926805.573},
    {1000671620, 161929102.274},
    {1000681620, 161928788.364},
    {1000691620, 161934002.277},
    {1000701620, 161935773.604},
    {1000711620, 161943282.776},
    {1000721620, 161947214.837},
    {1000731620, 161957294.083},
    {1000741620, 161963499.142},
    {1000751620, 161975844.},
    {1000761620, 161984431.},
    {1000611630, 162953570.},
    {1000621630, 162945550.},
    {1000631630, 162939195.675},
    {1000641630, 162934176.855},
    {1000651630, 162930654.659},
    {1000661630, 162928738.284},
    {1000671630, 162928741.027},
    {1000681630, 162930040.797},
    {1000691630, 162932659.172},
    {1000701630, 162936339.632},
    {1000711630, 162941179.000},
    {1000721630, 162947112.946},
    {1000731630, 162954337.110},
    {1000741630, 162962524.342},
    {1000751630, 162972079.860},
    {1000761630, 162982410.},
    {1000621640, 163948360.},
    {1000631640, 163942744.},
    {1000641640, 163935830.},
    {1000651640, 163933357.961},
    {1000661640, 163929181.874},
    {1000671640, 163930240.273},
    {1000681640, 163929208.791},
    {1000691640, 163933543.614},
    {1000701640, 163934494.934},
    {1000711640, 163941339.000},
    {1000721640, 163944370.845},
    {1000731640, 163953534.000},
    {1000741640, 163958960.683},
    {1000751640, 163970452.870},
    {1000761640, 163978021.712},
    {1000771640, 163991909.},
    {1000621650, 164952970.},
    {1000631650, 164945587.},
    {1000641650, 164939360.},
    {1000651650, 164934980.},
    {1000661650, 164931710.456},
    {1000671650, 164930328.835},
    {1000681650, 164930734.496},
    {1000691650, 164932443.140},
    {1000701650, 164935270.241},
    {1000711650, 164939406.758},
    {1000721650, 164944567.000},
    {1000731650, 164950780.572},
    {1000741650, 164958280.788},
    {1000751650, 164967102.660},
    {1000761650, 164976602.},
    {1000771650, 164987501.},
    {1000631660, 165949620.},
    {1000641660, 165941460.},
    {1000651660, 165937859.521},
    {1000661660, 165932813.863},
    {1000671660, 165932290.927},
    {1000681660, 165930299.530},
    {1000691660, 165933560.600},
    {1000701660, 165933874.749},
    {1000711660, 165939859.000},
    {1000721660, 165942180.000},
    {1000731660, 165950512.000},
    {1000741660, 165955031.210},
    {1000751660, 165965760.821},
    {1000761660, 165972692.476},
    {1000771660, 165985664.},
    {1000781660, 165994855.},
    {1000631670, 166952890.},
    {1000641670, 166945450.},
    {1000651670, 166939960.},
    {1000661670, 166935661.379},
    {1000671670, 166933138.550},
    {1000681670, 166932054.617},
    {1000691670, 166932856.192},
    {1000701670, 166934952.988},
    {1000711670, 166938270.000},
    {1000721670, 166942600.000},
    {1000731670, 166948093.000},
    {1000741670, 166954804.560},
    {1000751670, 166962595.},
    {1000761670, 166971548.768},
    {1000771670, 166981666.315},
    {1000781670, 166992695.},
    {1000641680, 167948080.},
    {1000651680, 167943400.},
    {1000661680, 167937133.273},
    {1000671680, 167935522.173},
    {1000681680, 167932376.688},
    {1000691680, 167934177.409},
    {1000701680, 167933889.602},
    {1000711680, 167938735.635},
    {1000721680, 167940568.000},
    {1000731680, 167948047.000},
    {1000741680, 167951805.537},
    {1000751680, 167961572.608},
    {1000761680, 167967807.751},
    {1000771680, 167979906.642},
    {1000781680, 167988128.665},
    {1000641690, 168952600.},
    {1000651690, 168945970.},
    {1000661690, 168940313.531},
    {1000671690, 168936878.189},
    {1000681690, 168934596.850},
    {1000691690, 168934217.889},
    {1000701690, 168935182.512},
    {1000711690, 168937644.149},
    {1000721690, 168941259.000},
    {1000731690, 168946011.000},
    {1000741690, 168951778.845},
    {1000751690, 168958766.063},
    {1000761690, 168967017.574},
    {1000771690, 168976298.488},
    {1000781690, 168986567.},
    {1000791690, 168998080.},
    {1000651700, 169949840.},
    {1000661700, 169942390.},
    {1000671700, 169939624.846},
    {1000681700, 169935470.230},
    {1000691700, 169935806.032},
    {1000701700, 169934766.376},
    {1000711700, 169938478.365},
    {1000721700, 169939609.000},
    {1000731700, 169946175.000},
    {1000741700, 169949231.588},
    {1000751700, 169958220.071},
    {1000761700, 169963578.454},
    {1000771700, 169974922.},
    {1000781700, 169982496.345},
    {1000791700, 169995972.},
    {1000651710, 170952730.},
    {1000661710, 170946120.},
    {1000671710, 170941471.022},
    {1000681710, 170938035.681},
    {1000691710, 170936433.871},
    {1000701710, 170936330.208},
    {1000711710, 170937916.960},
    {1000721710, 170940492.000},
    {1000731710, 170944476.000},
    {1000741710, 170949451.000},
    {1000751710, 170955716.000},
    {1000761710, 170963173.969},
    {1000771710, 170971640.252},
    {1000781710, 170981245.248},
    {1000791710, 170991875.791},
    {1000801710, 171003529.},
    {1000661720, 171948460.},
    {1000671720, 171944730.},
    {1000681720, 171939361.858},
    {1000691720, 171938405.521},
    {1000701720, 171936385.872},
    {1000711720, 171939089.103},
    {1000721720, 171939449.716},
    {1000731720, 171944895.000},
    {1000741720, 171947292.000},
    {1000751720, 171955419.665},
    {1000761720, 171960017.317},
    {1000771720, 171970607.036},
    {1000781720, 171977350.921},
    {1000791720, 171989942.284},
    {1000801720, 171998808.967},
    {1000661730, 172952830.},
    {1000671730, 172947020.},
    {1000681730, 172942400.},
    {1000691730, 172939608.371},
    {1000701730, 172938215.136},
    {1000711730, 172938934.029},
    {1000721730, 172940513.000},
    {1000731730, 172943750.000},
    {1000741730, 172947689.000},
    {1000751730, 172953243.000},
    {1000761730, 172959808.465},
    {1000771730, 172967505.636},
    {1000781730, 172976443.058},
    {1000791730, 172986240.924},
    {1000801730, 172997091.},
    {1000671740, 173950950.},
    {1000681740, 173944230.},
    {1000691740, 173942172.953},
    {1000701740, 173938866.437},
    {1000711740, 173940340.854},
    {1000721740, 173940046.141},
    {1000731740, 173944454.000},
    {1000741740, 173946079.000},
    {1000751740, 173953115.000},
    {1000761740, 173957063.507},
    {1000771740, 173966861.045},
    {1000781740, 173972819.528},
    {1000791740, 173984717.},
    {1000801740, 173992864.748},
    {1000671750, 174953620.},
    {1000681750, 174947770.},
    {1000691750, 174943841.200},
    {1000701750, 174941280.797},
    {1000711750, 174940775.191},
    {1000721750, 174941509.187},
    {1000731750, 174943737.000},
    {1000741750, 174946717.000},
    {1000751750, 174951381.000},
    {1000761750, 174956945.313},
    {1000771750, 174964149.589},
    {1000781750, 174972409.721},
    {1000791750, 174981303.712},
    {1000801750, 174991440.747},
    {1000681760, 175949940.},
    {1000691760, 175946999.449},
    {1000701760, 175942576.447},
    {1000711760, 175942689.680},
    {1000721760, 175941407.628},
    {1000731760, 175944857.000},
    {1000741760, 175945634.000},
    {1000751760, 175951623.000},
    {1000761760, 175954806.000},
    {1000771760, 175963650.389},
    {1000781760, 175968938.362},
    {1000791760, 175980250.432},
    {1000801760, 175987360.863},
    {1000811760, 176000624.028},
    {1000681770, 176953990.},
    {1000691770, 176949040.},
    {1000701770, 176945265.586},
    {1000711770, 176943761.525},
    {1000721770, 176943227.717},
    {1000731770, 176944479.469},
    {1000741770, 176946643.000},
    {1000751770, 176950328.000},
    {1000761770, 176954965.628},
    {1000771770, 176961301.500},
    {1000781770, 176968469.537},
    {1000791770, 176976870.439},
    {1000801770, 176986277.319},
    {1000811770, 176996430.829},
    {1000691780, 177952640.},
    {1000701780, 177946651.444},
    {1000711780, 177945958.018},
    {1000721780, 177943705.833},
    {1000731780, 177945678.},
    {1000741780, 177945883.303},
    {1000751780, 177950989.000},
    {1000761780, 177953253.627},
    {1000771780, 177961082.000},
    {1000781780, 177965649.523},
    {1000791780, 177976031.920},
    {1000801780, 177982483.769},
    {1000811780, 177994854.},
    {1000821780, 178003831.243},
    {1000691790, 178955340.},
    {1000701790, 178950040.},
    {1000711790, 178947330.935},
    {1000721790, 178945823.212},
    {1000731790, 178945936.555},
    {1000741790, 178947077.043},
    {1000751790, 178949989.130},
    {1000761790, 178953816.881},
    {1000771790, 178959120.178},
    {1000781790, 178965358.953},
    {1000791790, 178973173.654},
    {1000801790, 178981831.329},
    {1000811790, 178991110.696},
    {1000821790, 179002201.112},
    {1000701800, 179952120.},
    {1000711800, 179949888.250},
    {1000721800, 179946557.042},
    {1000731800, 179947464.832},
    {1000741800, 179946710.805},
    {1000751800, 179950791.568},
    {1000761800, 179952375.485},
    {1000771800, 179959229.446},
    {1000781800, 179963031.955},
    {1000791800, 179972523.397},
    {1000801800, 179978260.335},
    {1000811800, 179990056.524},
    {1000821800, 179997928.286},
    {1000701810, 180955890.},
    {1000711810, 180951908.000},
    {1000721810, 180949108.338},
    {1000731810, 180947995.769},
    {1000741810, 180948197.783},
    {1000751810, 180950057.673},
    {1000761810, 180953247.188},
    {1000771810, 180957625.456},
    {1000781810, 180963097.588},
    {1000791810, 180970079.047},
    {1000801810, 180977819.371},
    {1000811810, 180986259.979},
    {1000821810, 180996653.310},
    {1000711820, 181955040.},
    {1000721820, 181950561.185},
    {1000731820, 181950151.853},
    {1000741820, 181948203.945},
    {1000751820, 181951209.869},
    {1000761820, 181952110.187},
    {1000771820, 181958076.296},
    {1000781820, 181961171.823},
    {1000791820, 181969617.874},
    {1000801820, 181974689.351},
    {1000811820, 181985713.159},
    {1000821820, 181992672.466},
    {1000711830, 182957363.000},
    {1000721830, 182953530.444},
    {1000731830, 182951372.620},
    {1000741830, 182950222.748},
    {1000751830, 182950819.638},
    {1000761830, 182953124.719},
    {1000771830, 182956839.968},
    {1000781830, 182961596.804},
    {1000791830, 182967590.635},
    {1000801830, 182974444.783},
    {1000811830, 182982192.839},
    {1000821830, 182991872.098},
    {1000711840, 183960910.},
    {1000721840, 183955446.243},
    {1000731840, 183954007.694},
    {1000741840, 183950930.916},
    {1000751840, 183952522.809},
    {1000761840, 183952488.536},
    {1000771840, 183957476.000},
    {1000781840, 183959915.113},
    {1000791840, 183967451.524},
    {1000801840, 183971713.528},
    {1000811840, 183981885.851},
    {1000821840, 183988135.701},
    {1000831840, 184001274.756},
    {1000711850, 184963620.},
    {1000721850, 184958862.000},
    {1000731850, 184955559.084},
    {1000741850, 184953418.974},
    {1000751850, 184952954.486},
    {1000761850, 184954041.741},
    {1000771850, 184956698.000},
    {1000781850, 184960613.659},
    {1000791850, 184965789.569},
    {1000801850, 184971899.388},
    {1000811850, 184978789.050},
    {1000821850, 184987610.004},
    {1000831850, 184997600.},
    {1000721860, 185960897.000},
    {1000731860, 185958550.667},
    {1000741860, 185954362.771},
    {1000751860, 185954985.595},
    {1000761860, 185953835.044},
    {1000771860, 185957944.153},
    {1000781860, 185959350.812},
    {1000791860, 185965952.703},
    {1000801860, 185969362.272},
    {1000811860, 185978650.841},
    {1000821860, 185984238.331},
    {1000831860, 185996643.681},
    {1000841860, 186004393.241},
    {1000721870, 186964770.},
    {1000731870, 186960386.000},
    {1000741870, 186957158.841},
    {1000751870, 186955750.071},
    {1000761870, 186955747.422},
    {1000771870, 186957542.000},
    {1000781870, 186960616.976},
    {1000791870, 186964543.155},
    {1000801870, 186969814.428},
    {1000811870, 186975906.348},
    {1000821870, 186983910.895},
    {1000831870, 186993147.184},
    {1000841870, 187003041.054},
    {1000721880, 187966850.},
    {1000731880, 187963916.000},
    {1000741880, 187958486.177},
    {1000751880, 187958111.510},
    {1000761880, 187955835.174},
    {1000771880, 187958828.095},
    {1000781880, 187959388.889},
    {1000791880, 187965349.392},
    {1000801880, 187967566.887},
    {1000811880, 187976020.886},
    {1000821880, 187980874.815},
    {1000831880, 187992286.943},
    {1000841880, 187999415.569},
    {1000721890, 188970840.},
    {1000731890, 188965830.},
    {1000741890, 188961763.000},
    {1000751890, 188959226.020},
    {1000761890, 188958144.162},
    {1000771890, 188958715.028},
    {1000781890, 188960831.282},
    {1000791890, 188963948.286},
    {1000801890, 188968194.927},
    {1000811890, 188973588.471},
    {1000821890, 188980807.000},
    {1000831890, 188989194.984},
    {1000841890, 188998473.429},
    {1000731900, 189969390.},
    {1000741900, 189963090.589},
    {1000751900, 189961744.260},
    {1000761900, 189958443.702},
    {1000771900, 189960541.215},
    {1000781900, 189959929.707},
    {1000791900, 189964698.390},
    {1000801900, 189966322.735},
    {1000811900, 189973828.},
    {1000821900, 189978081.999},
    {1000831900, 189988621.561},
    {1000841900, 189995100.569},
    {1000731910, 190971560.},
    {1000741910, 190966531.000},
    {1000751910, 190963121.551},
    {1000761910, 190960926.361},
    {1000771910, 190960589.293},
    {1000781910, 190961672.912},
    {1000791910, 190963702.248},
    {1000801910, 190967157.160},
    {1000811910, 190971784.199},
    {1000821910, 190978276.000},
    {1000831910, 190985786.556},
    {1000841910, 190994558.462},
    {1000851910, 191004147.909},
    {1000731920, 191975140.},
    {1000741920, 191968170.},
    {1000751920, 191966088.000},
    {1000761920, 191961476.998},
    {1000771920, 191962600.247},
    {1000781920, 191961038.746},
    {1000791920, 191964813.694},
    {1000801920, 191965634.702},
    {1000811920, 191972225.000},
    {1000821920, 191975775.008},
    {1000831920, 191985469.058},
    {1000841920, 191991335.925},
    {1000851920, 192003151.707},
    {1000741930, 192971780.},
    {1000751930, 192967541.000},
    {1000761930, 192964147.870},
    {1000771930, 192962921.587},
    {1000781930, 192962982.380},
    {1000791930, 192964137.257},
    {1000801930, 192966652.658},
    {1000811930, 192970501.998},
    {1000821930, 192976173.234},
    {1000831930, 192982959.813},
    {1000841930, 192991025.678},
    {1000851930, 192999927.418},
    {1000861930, 193009707.979},
    {1000741940, 193973670.},
    {1000751940, 193970760.},
    {1000761940, 193965177.240},
    {1000771940, 193965073.536},
    {1000781940, 193962680.850},
    {1000791940, 193965417.754},
    {1000801940, 193965449.112},
    {1000811940, 193971081.412},
    {1000821940, 193974012.250},
    {1000831940, 193982785.},
    {1000841940, 193988186.101},
    {1000851940, 193999236.139},
    {1000861940, 194006144.389},
    {1000751950, 194972540.},
    {1000761950, 194968318.000},
    {1000771950, 194965974.730},
    {1000781950, 194964791.719},
    {1000791950, 194965035.225},
    {1000801950, 194966720.540},
    {1000811950, 194969774.268},
    {1000821950, 194974542.922},
    {1000831950, 194980648.781},
    {1000841950, 194988125.532},
    {1000851950, 194996268.546},
    {1000861950, 195005421.673},
    {1000751960, 195975800.},
    {1000761960, 195969641.463},
    {1000771960, 195968397.112},
    {1000781960, 195964952.091},
    {1000791960, 195966569.908},
    {1000801960, 195965832.560},
    {1000811960, 195970481.193},
    {1000821960, 195972774.233},
    {1000831960, 195980666.509},
    {1000841960, 195985525.902},
    {1000851960, 195995799.619},
    {1000861960, 196002115.998},
    {1000751970, 196977990.},
    {1000761970, 196972830.},
    {1000771970, 196969655.415},
    {1000781970, 196967340.687},
    {1000791970, 196966568.786},
    {1000801970, 196967212.847},
    {1000811970, 196969575.890},
    {1000821970, 196973431.166},
    {1000831970, 196978865.099},
    {1000841970, 196985659.522},
    {1000851970, 196993189.187},
    {1000861970, 197001584.620},
    {1000751980, 197981600.},
    {1000761980, 197974410.},
    {1000771980, 197972280.},
    {1000781980, 197967894.920},
    {1000791980, 197968242.420},
    {1000801980, 197966768.602},
    {1000811980, 197970483.065},
    {1000821980, 197972034.077},
    {1000831980, 197979206.000},
    {1000841980, 197983389.132},
    {1000851980, 197992784.},
    {1000861980, 197998679.156},
    {1000761990, 198978010.},
    {1000771990, 198973805.301},
    {1000781990, 198970595.224},
    {1000791990, 198968765.282},
    {1000801990, 198968280.643},
    {1000811990, 198969877.000},
    {1000821990, 198972912.680},
    {1000831990, 198977673.010},
    {1000841990, 198983667.115},
    {1000851990, 198990527.654},
    {1000861990, 198998389.856},
    {1000871990, 199007258.594},
    {1000762000, 199979840.},
    {1000772000, 199976800.},
    {1000782000, 199971442.807},
    {1000792000, 199970756.456},
    {1000802000, 199968326.590},
    {1000812000, 199970963.258},
    {1000822000, 199971818.893},
    {1000832000, 199978131.179},
    {1000842000, 199981798.790},
    {1000852000, 199990351.015},
    {1000862000, 199995690.431},
    {1000872000, 200006586.003},
    {1000762010, 200983640.},
    {1000772010, 200978640.},
    {1000782010, 200974513.112},
    {1000792010, 200971657.484},
    {1000802010, 200970302.839},
    {1000812010, 200970822.212},
    {1000822010, 200972882.917},
    {1000832010, 200977010.416},
    {1000842010, 200982259.806},
    {1000852010, 200988417.147},
    {1000862010, 200995628.010},
    {1000872010, 201003866.593},
    {1000882010, 201012712.},
    {1000762020, 201985950.},
    {1000772020, 201981990.},
    {1000782020, 201975639.000},
    {1000792020, 201973856.000},
    {1000802020, 201970643.400},
    {1000812020, 201972102.441},
    {1000822020, 201972152.026},
    {1000832020, 201977733.861},
    {1000842020, 201980757.657},
    {1000852020, 201988630.302},
    {1000862020, 201993264.277},
    {1000872020, 202003320.},
    {1000882020, 202009759.744},
    {1000772030, 202984230.},
    {1000782030, 202978930.},
    {1000792030, 202975154.446},
    {1000802030, 202972872.837},
    {1000812030, 202972344.593},
    {1000822030, 202973391.126},
    {1000832030, 202976892.779},
    {1000842030, 202981416.133},
    {1000852030, 202986942.990},
    {1000862030, 202993387.741},
    {1000872030, 203000940.729},
    {1000882030, 203009304.274},
    {1000772040, 203989600.},
    {1000782040, 203980760.},
    {1000792040, 203977831.},
    {1000802040, 203973493.981},
    {1000812040, 203973863.900},
    {1000822040, 203973043.981},
    {1000832040, 203977836.062},
    {1000842040, 203980310.339},
    {1000852040, 203987251.198},
    {1000862040, 203991429.922},
    {1000872040, 204000652.059},
    {1000882040, 204006491.866},
    {1000782050, 204986080.},
    {1000792050, 204979850.},
    {1000802050, 204976073.417},
    {1000812050, 204974427.801},
    {1000822050, 204974482.157},
    {1000832050, 204977386.694},
    {1000842050, 204981203.091},
    {1000852050, 204986075.861},
    {1000862050, 204991718.840},
    {1000872050, 204998593.858},
    {1000882050, 205006268.245},
    {1000782060, 205989660.},
    {1000792060, 205984740.},
    {1000802060, 205977514.401},
    {1000812060, 205976110.589},
    {1000822060, 205974465.683},
    {1000832060, 205978499.317},
    {1000842060, 205980473.991},
    {1000852060, 205986656.933},
    {1000862060, 205990214.219},
    {1000872060, 205998666.132},
    {1000882060, 206003828.053},
    {1000892060, 206014452.},
    {1000792070, 206988400.},
    {1000802070, 206982300.000},
    {1000812070, 206977419.712},
    {1000822070, 206975897.297},
    {1000832070, 206978471.022},
    {1000842070, 206981593.762},
    {1000852070, 206985800.332},
    {1000862070, 206990730.254},
    {1000872070, 206996946.478},
    {1000882070, 207003799.159},
    {1000892070, 207011965.830},
    {1000792080, 207993450.},
    {1000802080, 207985759.000},
    {1000812080, 207982019.001},
    {1000822080, 207976652.481},
    {1000832080, 207979742.530},
    {1000842080, 207981246.092},
    {1000852080, 207986613.302},
    {1000862080, 207989634.687},
    {1000872080, 207997138.132},
    {1000882080, 208001841.122},
    {1000892080, 208011550.406},
    {1000902080, 208017900.275},
    {1000792090, 208997350.},
    {1000802090, 208990720.},
    {1000812090, 208985359.353},
    {1000822090, 208981090.461},
    {1000832090, 208980399.068},
    {1000842090, 208982430.836},
    {1000852090, 208986170.215},
    {1000862090, 208990414.510},
    {1000872090, 208995954.932},
    {1000882090, 209001990.455},
    {1000892090, 209009494.762},
    {1000902090, 209017752.974},
    {1000792100, 210002500.},
    {1000802100, 209994240.},
    {1000812100, 209990073.958},
    {1000822100, 209984188.861},
    {1000832100, 209984120.705},
    {1000842100, 209982874.076},
    {1000852100, 209987147.898},
    {1000862100, 209989689.107},
    {1000872100, 209996422.409},
    {1000882100, 210000494.169},
    {1000892100, 210009436.052},
    {1000902100, 210015093.642},
    {1000802110, 210999330.},
    {1000812110, 210993475.000},
    {1000822110, 210988737.125},
    {1000832110, 210987269.741},
    {1000842110, 210986653.562},
    {1000852110, 210987496.614},
    {1000862110, 210990601.110},
    {1000872110, 210995555.723},
    {1000882110, 211000893.214},
    {1000892110, 211007731.899},
    {1000902110, 211014929.468},
    {1000802120, 212002960.},
    {1000812120, 211998335.},
    {1000822120, 211991897.703},
    {1000832120, 211991286.026},
    {1000842120, 211988868.376},
    {1000852120, 211990737.688},
    {1000862120, 211990703.919},
    {1000872120, 211996225.652},
    {1000882120, 211999786.715},
    {1000892120, 212007813.171},
    {1000902120, 212012987.595},
    {1000912120, 212023202.993},
    {1000802130, 213008230.},
    {1000812130, 213001915.000},
    {1000822130, 212996562.894},
    {1000832130, 212994385.067},
    {1000842130, 212992857.623},
    {1000852130, 212992936.978},
    {1000862130, 212993883.069},
    {1000872130, 212996186.041},
    {1000882130, 213000384.258},
    {1000892130, 213006609.020},
    {1000902130, 213013009.223},
    {1000912130, 213021109.239},
    {1000802140, 214012000.},
    {1000812140, 214006940.},
    {1000822140, 213999805.917},
    {1000832140, 213998711.926},
    {1000842140, 213995201.683},
    {1000852140, 213996372.066},
    {1000862140, 213995362.956},
    {1000872140, 213998971.333},
    {1000882140, 214000099.727},
    {1000892140, 214006918.488},
    {1000902140, 214011500.159},
    {1000912140, 214020918.483},
    {1000802150, 215017400.},
    {1000812150, 215010640.},
    {1000822150, 215004741.},
    {1000832150, 215001769.823},
    {1000842150, 214999420.146},
    {1000852150, 214998652.849},
    {1000862150, 214998745.890},
    {1000872150, 215000341.838},
    {1000882150, 215002720.420},
    {1000892150, 215006474.511},
    {1000902150, 215011724.774},
    {1000912150, 215019182.929},
    {1000802160, 216021320.},
    {1000812160, 216015800.},
    {1000822160, 216008030.},
    {1000832160, 216006305.989},
    {1000842160, 216001915.186},
    {1000852160, 216002423.555},
    {1000862160, 216000271.859},
    {1000872160, 216003189.865},
    {1000882160, 216003533.423},
    {1000892160, 216008743.482},
    {1000902160, 216011056.007},
    {1000912160, 216019108.913},
    {1000812170, 217019660.},
    {1000822170, 217013140.},
    {1000832170, 217009372.000},
    {1000842170, 217006318.159},
    {1000852170, 217004719.222},
    {1000862170, 217003928.018},
    {1000872170, 217004632.282},
    {1000882170, 217006320.726},
    {1000892170, 217009343.872},
    {1000902170, 217013116.701},
    {1000912170, 217018325.363},
    {1000922170, 217024661.},
    {1000812180, 218024790.},
    {1000822180, 218016590.},
    {1000832180, 218014188.000},
    {1000842180, 218008973.546},
    {1000852180, 218008694.723},
    {1000862180, 218005601.586},
    {1000872180, 218007578.653},
    {1000882180, 218007140.631},
    {1000892180, 218011641.640},
    {1000902180, 218013276.331},
    {1000912180, 218020058.579},
    {1000922180, 218023523.472},
    {1000822190, 219021770.},
    {1000832190, 219017480.},
    {1000842190, 219013614.000},
    {1000852190, 219011161.848},
    {1000862190, 219009480.361},
    {1000872190, 219009252.427},
    {1000882190, 219010085.484},
    {1000892190, 219012420.730},
    {1000902190, 219015537.481},
    {1000912190, 219019904.029},
    {1000922190, 219024999.130},
    {1000932190, 219031430.},
    {1000822200, 220025410.},
    {1000832200, 220022350.},
    {1000842200, 220016386.000},
    {1000852200, 220015433.000},
    {1000862200, 220011394.130},
    {1000872200, 220012327.702},
    {1000882200, 220011025.872},
    {1000892200, 220014754.854},
    {1000902200, 220015748.148},
    {1000912200, 220021705.},
    {1000922200, 220024620.},
    {1000932200, 220032540.},
    {1000832210, 221025870.},
    {1000842210, 221021228.000},
    {1000852210, 221018017.000},
    {1000862210, 221015537.076},
    {1000872210, 221014255.163},
    {1000882210, 221013917.680},
    {1000892210, 221015591.579},
    {1000902210, 221018184.072},
    {1000912210, 221021874.941},
    {1000922210, 221026284.},
    {1000932210, 221032040.},
    {1000832220, 222030780.},
    {1000842220, 222024140.000},
    {1000852220, 222022494.000},
    {1000862220, 222017578.246},
    {1000872220, 222017552.192},
    {1000882220, 222015374.846},
    {1000892220, 222017844.181},
    {1000902220, 222018468.521},
    {1000912220, 222023784.},
    {1000922220, 222026003.},
    {1000932220, 222033300.},
    {1000832230, 223034500.},
    {1000842230, 223029070.},
    {1000852230, 223025151.000},
    {1000862230, 223021889.286},
    {1000872230, 223019736.013},
    {1000882230, 223018502.327},
    {1000892230, 223019137.747},
    {1000902230, 223020811.853},
    {1000912230, 223023962.614},
    {1000922230, 223027739.187},
    {1000932230, 223032850.},
    {1000832240, 224039470.},
    {1000842240, 224032110.},
    {1000852240, 224029749.000},
    {1000862240, 224024095.805},
    {1000872240, 224023398.000},
    {1000882240, 224020211.968},
    {1000892240, 224021723.163},
    {1000902240, 224021464.382},
    {1000912240, 224025617.614},
    {1000922240, 224027605.163},
    {1000932240, 224034220.},
    {1000842250, 225037070.},
    {1000852250, 225032630.},
    {1000862250, 225028485.574},
    {1000872250, 225025572.682},
    {1000882250, 225023611.857},
    {1000892250, 225023229.987},
    {1000902250, 225023951.363},
    {1000912250, 225026131.009},
    {1000922250, 225029391.350},
    {1000932250, 225033910.892},
    {1000842260, 226040310.},
    {1000852260, 226037160.},
    {1000862260, 226030861.382},
    {1000872260, 226029566.000},
    {1000882260, 226025410.330},
    {1000892260, 226026098.383},
    {1000902260, 226024903.383},
    {1000912260, 226027948.082},
    {1000922260, 226029339.101},
    {1000932260, 226035188.},
    {1000842270, 227045390.},
    {1000852270, 227040240.},
    {1000862270, 227035304.396},
    {1000872270, 227031869.000},
    {1000882270, 227029178.349},
    {1000892270, 227027752.283},
    {1000902270, 227027704.227},
    {1000912270, 227028805.351},
    {1000922270, 227031156.773},
    {1000932270, 227034957.129},
    {1000852280, 228044750.},
    {1000862280, 228037835.418},
    {1000872280, 228035823.175},
    {1000882280, 228031070.728},
    {1000892280, 228031021.547},
    {1000902280, 228028741.272},
    {1000912280, 228031051.673},
    {1000922280, 228031371.492},
    {1000932280, 228036066.866},
    {1000942280, 228038732.491},
    {1000852290, 229048120.},
    {1000862290, 229042257.277},
    {1000872290, 229038298.000},
    {1000882290, 229034942.262},
    {1000892290, 229032955.884},
    {1000902290, 229031762.713},
    {1000912290, 229032097.236},
    {1000922290, 229033506.280},
    {1000932290, 229036264.139},
    {1000942290, 229040143.614},
    {1000862300, 230045140.},
    {1000872300, 230042416.349},
    {1000882300, 230037054.781},
    {1000892300, 230036327.000},
    {1000902300, 230033134.130},
    {1000912300, 230034541.047},
    {1000922300, 230033940.096},
    {1000932300, 230037827.926},
    {1000942300, 230039650.283},
    {1000952300, 230046090.},
    {1000862310, 231049870.},
    {1000872310, 231045158.000},
    {1000882310, 231041027.087},
    {1000892310, 231038393.000},
    {1000902310, 231036304.628},
    {1000912310, 231035884.243},
    {1000922310, 231036293.861},
    {1000932310, 231038245.364},
    {1000942310, 231041101.511},
    {1000952310, 231045560.},
    {1000872320, 232049368.},
    {1000882320, 232043475.270},
    {1000892320, 232042034.000},
    {1000902320, 232038055.760},
    {1000912320, 232038591.737},
    {1000922320, 232037156.297},
    {1000932320, 232040109.},
    {1000942320, 232041184.582},
    {1000952320, 232046450.},
    {1000962320, 232049817.},
    {1000872330, 233052640.},
    {1000882330, 233047582.000},
    {1000892330, 233044346.000},
    {1000902330, 233041582.278},
    {1000912330, 233040247.222},
    {1000922330, 233039635.525},
    {1000932330, 233040740.989},
    {1000942330, 233042997.716},
    {1000952330, 233046445.},
    {1000962330, 233050770.001},
    {1000882340, 234050342.000},
    {1000892340, 234048139.000},
    {1000902340, 234043601.407},
    {1000912340, 234043307.161},
    {1000922340, 234040952.306},
    {1000932340, 234042895.256},
    {1000942340, 234043317.387},
    {1000952340, 234047731.},
    {1000962340, 234050160.237},
    {1000972340, 234057267.},
    {1000882350, 235054970.},
    {1000892350, 235050840.000},
    {1000902350, 235047255.000},
    {1000912350, 235045399.000},
    {1000922350, 235043930.131},
    {1000932350, 235044063.487},
    {1000942350, 235045286.206},
    {1000952350, 235047908.245},
    {1000962350, 235051542.},
    {1000972350, 235056580.},
    {1000892360, 236054988.000},
    {1000902360, 236049657.000},
    {1000912360, 236048668.000},
    {1000922360, 236045568.210},
    {1000932360, 236046569.744},
    {1000942360, 236046058.109},
    {1000952360, 236049428.},
    {1000962360, 236051374.477},
    {1000972360, 236057480.},
    {1000892370, 237058270.},
    {1000902370, 237053629.000},
    {1000912370, 237051023.000},
    {1000922370, 237048730.378},
    {1000932370, 237048173.649},
    {1000942370, 237048409.830},
    {1000952370, 237049996.},
    {1000962370, 237052869.294},
    {1000972370, 237057100.},
    {1000982370, 237062197.789},
    {1000902380, 238056496.},
    {1000912380, 238054637.000},
    {1000922380, 238050788.423},
    {1000932380, 238050946.611},
    {1000942380, 238049560.111},
    {1000952380, 238051984.542},
    {1000962380, 238053081.420},
    {1000972380, 238058204.},
    {1000982380, 238061490.},
    {1000902390, 239060770.},
    {1000912390, 239057260.},
    {1000922390, 239054293.475},
    {1000932390, 239052939.241},
    {1000942390, 239052163.591},
    {1000952390, 239053024.699},
    {1000962390, 239054910.117},
    {1000972390, 239058241.},
    {1000982390, 239062529.},
    {1000992390, 239068230.},
    {1000912400, 240060980.},
    {1000922400, 240056593.356},
    {1000932400, 240056165.427},
    {1000942400, 240053813.750},
    {1000952400, 240055300.384},
    {1000962400, 240055529.681},
    {1000972400, 240059759.},
    {1000982400, 240062255.728},
    {1000992400, 240068920.},
    {1000912410, 241064080.},
    {1000922410, 241060330.},
    {1000932410, 241058252.636},
    {1000942410, 241056851.661},
    {1000952410, 241056829.349},
    {1000962410, 241057653.170},
    {1000972410, 241060155.},
    {1000982410, 241063690.},
    {1000992410, 241068560.},
    {1001002410, 241074210.},
    {1000922420, 242062932.},
    {1000932420, 242061641.379},
    {1000942420, 242058742.809},
    {1000952420, 242059549.364},
    {1000962420, 242058836.039},
    {1000972420, 242061982.},
    {1000982420, 242063754.274},
    {1000992420, 242069567.},
    {1001002420, 242073430.},
    {1000922430, 243066990.},
    {1000932430, 243064280.},
    {1000942430, 243062003.595},
    {1000952430, 243061381.302},
    {1000962430, 243061389.325},
    {1000972430, 243063007.791},
    {1000982430, 243065477.},
    {1000992430, 243069510.},
    {1001002430, 243074465.},
    {1000932440, 244067850.},
    {1000942440, 244064205.260},
    {1000952440, 244064285.052},
    {1000962440, 244062752.783},
    {1000972440, 244065180.979},
    {1000982440, 244066000.801},
    {1000992440, 244070883.},
    {1001002440, 244074038.},
    {1000932450, 245070800.},
    {1000942450, 245067826.058},
    {1000952450, 245066454.834},
    {1000962450, 245065491.454},
    {1000972450, 245066361.821},
    {1000982450, 245068048.677},
    {1000992450, 245071249.},
    {1001002450, 245075349.},
    {1001012450, 245080808.},
    {1000942460, 246070205.458},
    {1000952460, 246069775.},
    {1000962460, 246067223.841},
    {1000972460, 246068673.126},
    {1000982460, 246068805.531},
    {1000992460, 246072896.},
    {1001002460, 246075350.470},
    {1001012460, 246081713.},
    {1000942470, 247074190.},
    {1000952470, 247072093.},
    {1000962470, 247070354.131},
    {1000972470, 247070307.302},
    {1000982470, 247070965.463},
    {1000992470, 247073622.017},
    {1001002470, 247076945.},
    {1001012470, 247081522.},
    {1000952480, 248075753.},
    {1000962480, 248072349.862},
    {1000972480, 248073088.},
    {1000982480, 248072185.066},
    {1000992480, 248075471.},
    {1001002480, 248077186.463},
    {1001012480, 248082823.},
    {1001022480, 248086550.},
    {1000952490, 249078480.},
    {1000962490, 249075954.767},
    {1000972490, 249074987.676},
    {1000982490, 249074853.903},
    {1000992490, 249076411.},
    {1001002490, 249078927.550},
    {1001012490, 249082914.},
    {1001022490, 249087797.},
    {1000962500, 250078358.313},
    {1000972500, 250078316.698},
    {1000982500, 250076406.244},
    {1000992500, 250078612.},
    {1001002500, 250079521.034},
    {1001012500, 250084415.},
    {1001022500, 250087562.},
    {1000962510, 251082286.441},
    {1000972510, 251080762.009},
    {1000982510, 251079588.625},
    {1000992510, 251079993.586},
    {1001002510, 251081539.890},
    {1001012510, 251084774.376},
    {1001022510, 251088944.},
    {1001032510, 251094180.},
    {1000962520, 252084870.},
    {1000972520, 252084311.},
    {1000982520, 252081627.199},
    {1000992520, 252082979.865},
    {1001002520, 252082467.060},
    {1001012520, 252086432.},
    {1001022520, 252088966.908},
    {1001032520, 252095264.},
    {1000972530, 253086880.},
    {1000982530, 253085134.499},
    {1000992530, 253084825.715},
    {1001002530, 253085184.571},
    {1001012530, 253087144.},
    {1001022530, 253090564.103},
    {1001032530, 253095091.},
    {1001042530, 253100438.},
    {1000972540, 254090600.},
    {1000982540, 254087324.263},
    {1000992540, 254088022.199},
    {1001002540, 254086854.397},
    {1001012540, 254089592.},
    {1001022540, 254090955.661},
    {1001032540, 254096483.},
    {1001042540, 254100053.},
    {1000982550, 255091048.},
    {1000992550, 255090274.958},
    {1001002550, 255089964.038},
    {1001012550, 255091084.149},
    {1001022550, 255093191.404},
    {1001032550, 255096562.404},
    {1001042550, 255101268.},
    {1001052550, 255107068.},
    {1000982560, 256093442.},
    {1000992560, 256093599.},
    {1001002560, 256091774.469},
    {1001012560, 256093889.},
    {1001022560, 256094282.870},
    {1001032560, 256098494.030},
    {1001042560, 256101152.218},
    {1001052560, 256107890.},
    {1000992570, 257095979.},
    {1001002570, 257095106.078},
    {1001012570, 257095542.387},
    {1001022570, 257096887.830},
    {1001032570, 257099418.},
    {1001042570, 257102918.120},
    {1001052570, 257107578.},
    {1000992580, 258099520.},
    {1001002580, 258097077.},
    {1001012580, 258098431.496},
    {1001022580, 258098207.},
    {1001032580, 258101755.},
    {1001042580, 258103427.679},
    {1001052580, 258109285.},
    {1001062580, 258112983.},
    {1001002590, 259100597.},
    {1001012590, 259100511.},
    {1001022590, 259101032.},
    {1001032590, 259102902.},
    {1001042590, 259105596.},
    {1001052590, 259109491.866},
    {1001062590, 259114396.},
    {1001002600, 260102809.},
    {1001012600, 260103653.},
    {1001022600, 260102644.},
    {1001032600, 260105505.},
    {1001042600, 260106441.},
    {1001052600, 260111297.},
    {1001062600, 260114384.105},
    {1001072600, 260121659.},
    {1001012610, 261105828.},
    {1001022610, 261105697.},
    {1001032610, 261106884.},
    {1001042610, 261108773.401},
    {1001052610, 261111917.},
    {1001062610, 261115949.461},
    {1001072610, 261121455.},
    {1001012620, 262109101.},
    {1001022620, 262107464.},
    {1001032620, 262109612.},
    {1001042620, 262109925.},
    {1001052620, 262114072.},
    {1001062620, 262116336.679},
    {1001072620, 262122967.},
    {1001022630, 263110715.},
    {1001032630, 263111359.},
    {1001042630, 263112495.},
    {1001052630, 263114990.},
    {1001062630, 263118294.},
    {1001072630, 263122916.},
    {1001082630, 263128522.},
    {1001022640, 264112734.},
    {1001032640, 264114201.},
    {1001042640, 264113879.},
    {1001052640, 264117405.},
    {1001062640, 264118931.},
    {1001072640, 264124593.},
    {1001082640, 264128356.917},
    {1001032650, 265116193.},
    {1001042650, 265116684.},
    {1001052650, 265118613.},
    {1001062650, 265121093.},
    {1001072650, 265124914.},
    {1001082650, 265129792.986},
    {1001092650, 265135996.},
    {1001032660, 266119831.},
    {1001042660, 266118172.},
    {1001052660, 266121029.},
    {1001062660, 266121975.},
    {1001072660, 266126794.},
    {1001082660, 266130046.400},
    {1001092660, 266137374.},
    {1001042670, 267121789.},
    {1001052670, 267122465.},
    {1001062670, 267124357.},
    {1001072670, 267127501.},
    {1001082670, 267131673.},
    {1001092670, 267137189.},
    {1001102670, 267143768.},
    {1001042680, 268123968.},
    {1001052680, 268125671.},
    {1001062680, 268125392.},
    {1001072680, 268129692.},
    {1001082680, 268131865.},
    {1001092680, 268138649.},
    {1001102680, 268143478.},
    {1001052690, 269127911.},
    {1001062690, 269128627.},
    {1001072690, 269130416.},
    {1001082690, 269133753.},
    {1001092690, 269138822.},
    {1001102690, 269144752.124},
    {1001052700, 270131356.},
    {1001062700, 270130427.},
    {1001072700, 270133363.},
    {1001082700, 270134290.},
    {1001092700, 270140327.},
    {1001102700, 270144584.153},
    {1001062710, 271133933.},
    {1001072710, 271135256.},
    {1001082710, 271137170.},
    {1001092710, 271140744.},
    {1001102710, 271145946.},
    {1001062720, 272135890.},
    {1001072720, 272138264.},
    {1001082720, 272138495.},
    {1001092720, 272143406.},
    {1001102720, 272146020.},
    {1001112720, 272153273.},
    {1001062730, 273139580.},
    {1001072730, 273140240.},
    {1001082730, 273141679.},
    {1001092730, 273144399.},
    {1001102730, 273148560.},
    {1001112730, 273153127.},
    {1001072740, 274143548.},
    {1001082740, 274143304.},
    {1001092740, 274147245.},
    {1001102740, 274149411.},
    {1001112740, 274155253.},
    {1001072750, 275145670.},
    {1001082750, 275146668.},
    {1001092750, 275148820.},
    {1001102750, 275152033.},
    {1001112750, 275155939.},
    {1001082760, 276148455.},
    {1001092760, 276151594.},
    {1001102760, 276153025.},
    {1001112760, 276158334.},
    {1001122760, 276161410.},
    {1001082770, 277151899.},
    {1001092770, 277153268.},
    {1001102770, 277155914.},
    {1001112770, 277159069.},
    {1001122770, 277163641.},
    {1001092780, 278156307.},
    {1001102780, 278157040.},
    {1001112780, 278161493.},
    {1001122780, 278164156.},
    {1001132780, 278170578.},
    {1001092790, 279158075.},
    {1001102790, 279160097.},
    {1001112790, 279162722.},
    {1001122790, 279166542.},
    {1001132790, 279170950.},
    {1001102800, 280161311.},
    {1001112800, 280165138.},
    {1001122800, 280167147.},
    {1001132800, 280172930.},
    {1001102810, 281164511.},
    {1001112810, 281166360.},
    {1001122810, 281169746.},
    {1001132810, 281173480.},
    {1001112820, 282169119.},
    {1001122820, 282170496.},
    {1001132820, 282175672.},
    {1001112830, 283170544.},
    {1001122830, 283173270.},
    {1001132830, 283176571.},
    {1001122840, 284174156.},
    {1001132840, 284178727.},
    {1001122850, 285177117.},
    {1001132850, 285179727.},
    {1001142850, 285183643.},
    {1001132860, 286182208.},
    {1001142860, 286184235.},
    {1001132870, 287183389.},
    {1001142870, 287186783.},
    {1001152870, 287190704.},
    {1001142880, 288187572.},
    {1001152880, 288192740.},
    {1001142890, 289190419.},
    {1001152890, 289193627.},
    {1001162890, 289198162.},
    {1001152900, 290195975.},
    {1001162900, 290198638.},
    {1001152910, 291197071.},
    {1001162910, 291201077.},
    {1001172910, 291205535.},
    {1001162920, 292201742.},
    {1001172920, 292207463.},
    {1001162930, 293204487.},
    {1001172930, 293208236.},
    {1001182930, 293213562.},
    {1001172940, 294210462.},
    {1001182940, 294213921.},
    {1001182950, 295216240.},
  };
}

marley::MassTable::MassTable() : particle_masses_(std::move(particle_masses)),
  atomic_masses_(std::move(atomic_masses))
{
}
